@@ -34,6 +34,7 @@ Card: Highscreen Sound-Boostar 16 3D\n\
 ISAPNP: MDK1605=ADS7180,ADS7181\n\
 ISAPNP: ADS7150=ADS7150,ADS7151\n\
 ISAPNP: ADS7181=ADS7180,ADS7181\n\
+ISAPNP: LWC1061=ADS7180,ADS7181\n\
 ISAPNP: TER1411=ADS7180,ADS7181\n\
 ");
 
@@ -104,6 +105,10 @@ static unsigned int snd_card_ad1816a_pnpids[] = {
 	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_DEVICE(0x7181),    /* device */
 	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_FUNCTION(0x7180),  /* audio */
 	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_FUNCTION(0x7181),  /* mpu401 */
+	/* Highscreen Sound-Boostar 16 3D - added by Stefan Behnel */
+	(ISAPNP_VENDOR('L','W','C')<<16)|ISAPNP_DEVICE(0x1061),    /* device */
+	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_FUNCTION(0x7180),  /* audio */
+	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_FUNCTION(0x7181),  /* mpu401 */
 	/* Analog Devices AD1816A - Terratec Base 64 */
 	(ISAPNP_VENDOR('T','E','R')<<16)|ISAPNP_DEVICE(0x1411),    /* device */
 	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_FUNCTION(0x7180),  /* audio */
@@ -166,17 +171,19 @@ static int __init snd_card_ad1816a_resources(int dev,
 	int error;
 	static long no_alternatives[] = {-1};
 
-	if (snd_register_ioport(card, snd_mpu_port[dev], 2,
-			DRIVER_NAME" - MPU-401", NULL) < 0)
-		snd_mpu_port[dev] = -1;
-	else if (snd_register_interrupt(card,
-			DRIVER_NAME" - MPU-401", snd_mpu_irq[dev],
-			SND_IRQ_TYPE_ISA, snd_card_ad1816a_mpu_interrupt,
-			acard, no_alternatives, &acard->mpuirqptr) < 0) {
-		snd_unregister_ioports(card);
-		snd_mpu_port[dev] = -1;
+	if (snd_mpu_port[dev] > 0) {
+		if (snd_register_ioport(card, snd_mpu_port[dev], 2,
+				DRIVER_NAME" - MPU-401", NULL) < 0)
+			snd_mpu_port[dev] = -1;
+		else if (snd_register_interrupt(card,
+				DRIVER_NAME" - MPU-401", snd_mpu_irq[dev],
+				SND_IRQ_TYPE_ISA, snd_card_ad1816a_mpu_interrupt,
+				acard, no_alternatives, &acard->mpuirqptr) < 0) {
+			snd_unregister_ioports(card);
+			snd_mpu_port[dev] = -1;
+		}
 	}
-
+	
 	if ((error = snd_register_ioport(card, snd_port[dev], 16,
 			DRIVER_NAME" - SS", NULL)) < 0)
 		return error;
@@ -196,9 +203,11 @@ static int __init snd_card_ad1816a_resources(int dev,
 			no_alternatives, &acard->dma2ptr)) < 0)
 		return error;
 
-	if (snd_register_ioport(card, snd_fm_port[dev], 8,
-			DRIVER_NAME" - FM", NULL) < 0)
-		snd_fm_port[dev] = -1;
+	if (snd_fm_port[dev] > 0) {
+		if (snd_register_ioport(card, snd_fm_port[dev], 8,
+				DRIVER_NAME" - FM", NULL) < 0)
+			snd_fm_port[dev] = -1;
+	}
 
 	return 0;
 }
@@ -259,8 +268,9 @@ static int __init snd_card_ad1816a_isapnp(int dev,
 	snd_irq[dev] = pdev->irq_resource[0].start;
 
 	pdev = acard->devmpu;
-	if (pdev == NULL || pdev->activate(pdev) < 0) {
+	if (pdev == NULL || pdev->prepare(pdev) < 0) {
 		snd_mpu_port[dev] = -1;
+		acard->devmpu = NULL;
 		return 0;
 	}
 
@@ -350,7 +360,7 @@ static int __init snd_card_ad1816a_probe(int dev,
 
 	strcpy(card->abbreviation, "AD1816A");
 	strcpy(card->shortname, "ADI SoundPort AD1816A");
-	sprintf(card->longname, "%s soundcard, SS at 0x%x, irq %i, dma %i&%i",
+	sprintf(card->longname, "%s soundcard, SS at 0x%lx, irq %li, dma %li&%li",
 		card->shortname, codec->port, acard->irqptr->irq,
 		acard->dma1ptr->dma, acard->dma2ptr->dma);
 
