@@ -48,6 +48,7 @@ Card: Packard Bell Sound III 336 AM/SP\n\
 ISAPNP: AZT1008=AZT1008,AZT2001\n\
 ISAPNP: AZT2320=AZT0001,AZT0002\n\
 ISAPNP: AZT3002=AZT1004,AZT2001\n\
+ISAPNP: AZT3005=AZT1003,AZT2001\n\
 ISAPNP: AZT3000=AZT1003,AZT2001\n\
 ");
 
@@ -121,6 +122,10 @@ static unsigned int snd_card_azt2320_pnpids[] = {
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_DEVICE(0x3002),    /* device */
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x1004),  /* audio */
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x2001),  /* mpu401 */
+	/* --- */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_DEVICE(0x3005),    /* device */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x1003),  /* audio */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x2001),  /* mpu401 */
 	/* Packard Bell Sound III 336 AM/SP */
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_DEVICE(0x3000),    /* device */
 	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x1002),  /* audio */
