@@ -80,7 +80,7 @@ MODULE_PARM(snd_sbirq, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_sbirq, "IRQ # for CMI8330 SB driver. [IRQ]");
 MODULE_PARM(snd_sbdma8, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_sbdma8, "DMA8 for CMI8330 SB driver. [DMA8]");
-MODULE_PARM(snd_sbdma8_size, __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM(snd_sbdma8_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_sbdma8_size, "DMA8 size in kB for CMI8330 SB driver. [DMA8_SIZE]");
 MODULE_PARM(snd_sbdma16, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_sbdma16, "DMA16 for CMI8330 SB driver. [DMA16]");
@@ -273,8 +273,8 @@ static int snd_cmi8330_loud_switch(snd_kmixer_element_t *element,
 static int __init snd_cmi8330_resources(int dev, struct snd_cmi8330 *acard,
 					snd_card_t * card)
 {
-	static int possible_irqs[] = {-1};
-	static int possible_dmas[] = {-1};
+	static long possible_irqs[] = {-1};
+	static long possible_dmas[] = {-1};
 	int err;
 
 	err = snd_register_ioport(card, snd_wssport[dev],  8,
@@ -581,7 +581,7 @@ static int __init snd_cmi8330_probe(int dev, struct snd_cmi8330 *acard)
 
 	strcpy(card->abbreviation, "CMI8330/C3D");
 	strcpy(card->shortname, "C-Media CMI8330/C3D");
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma %li",
 		acard->wss.pcm->name,
 		codec->port,
 		acard->wss.irqptr->irq,
