@@ -37,6 +37,7 @@ Card: C-Media CMI8738 PCI\n\
 PCI: 0x13f6=0x0100\n\
 PCI: 0x13f6=0x0101\n\
 PCI: 0x13f6=0x0111\n\
+PCI: 0x13f6=0x0112\n\
 ");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
@@ -330,6 +331,16 @@ inline static unsigned int snd_cmipci_read(cmipci_t *cm, unsigned int cmd)
 	return inl(cm->iobase + cmd);
 }
 
+/* read/write operations for word register */
+inline static void snd_cmipci_write_w(cmipci_t *cm, unsigned int cmd, unsigned short data)
+{
+	outw(data, cm->iobase + cmd);
+}
+inline static unsigned short snd_cmipci_read_w(cmipci_t *cm, unsigned int cmd)
+{
+	return inw(cm->iobase + cmd);
+}
+
 /* bit operations for dword register */
 static void snd_cmipci_set_bit(cmipci_t *cm, unsigned int cmd, unsigned int flag)
 {
@@ -420,17 +431,17 @@ static int snd_cmipci_pcm_prepare(cmipci_t *cm, cmipci_pcm_t *rec,
 {
 	unsigned long flags;
 	unsigned int reg, freq, val;
-	unsigned short count;
 	snd_pcm_runtime_t *runtime = subchn->runtime;
 
-	rec->dma_size = snd_pcm_lib_transfer_size(subchn);
-	rec->frag_size = snd_pcm_lib_transfer_fragment(subchn);
 	rec->fmt = 0;
 	if (snd_pcm_format_width(runtime->format.format) == 16)
 		rec->fmt |= 0x02;
 	if (runtime->format.voices > 1)
 		rec->fmt |= 0x01;
 	rec->offset = virt_to_bus(runtime->dma_area->buf);
+	/* buffer and fragment sizes in frame */
+	rec->dma_size = snd_pcm_lib_transfer_size(subchn) >> sample_shift[rec->fmt];
+	rec->frag_size = snd_pcm_lib_transfer_fragment(subchn) >> sample_shift[rec->fmt];
 
 	spin_lock_irqsave(&cm->reg_lock, flags);
 
@@ -439,10 +450,8 @@ static int snd_cmipci_pcm_prepare(cmipci_t *cm, cmipci_pcm_t *rec,
 	snd_cmipci_write(cm, reg, rec->offset);
 	/* program sample counts */
 	reg = rec->ch ? CM_REG_CH1_FRAME2 : CM_REG_CH0_FRAME2;
-	count = (unsigned short)(rec->dma_size >> sample_shift[rec->fmt]) - 1;
-	outw(count, cm->iobase + reg);
-	count = (unsigned short)(rec->frag_size >> sample_shift[rec->fmt]) - 1;
-	outw(count, cm->iobase + reg + 2);
+	snd_cmipci_write_w(cm, reg, rec->dma_size - 1);
+	snd_cmipci_write_w(cm, reg + 2, rec->frag_size - 1);
 
 	/* set adc/dac flag */
 	val = rec->ch ? CM_CHADC1 : CM_CHADC0;
@@ -475,7 +484,6 @@ static int snd_cmipci_pcm_prepare(cmipci_t *cm, cmipci_pcm_t *rec,
 		val &= ~CM_CH0FMT_MASK;
 		val |= rec->fmt << CM_CH0FMT_SHIFT;
 	}
-	udelay(10);
 	snd_cmipci_write(cm, CM_REG_CHFORMAT, val);
 	//snd_printd("cmipci: chformat = %08x\n", val);
 
@@ -535,7 +543,6 @@ static int snd_cmipci_pcm_trigger(cmipci_t *cm, cmipci_pcm_t *rec,
 		/* reset */
 		cm->ctrl &= ~chen;
 		snd_cmipci_write(cm, CM_REG_FUNCTRL0, cm->ctrl | reset);
-		udelay(10);
 		snd_cmipci_write(cm, CM_REG_FUNCTRL0, cm->ctrl);
 	}
 	spin_unlock_irqrestore(&cm->reg_lock, flags);
@@ -552,8 +559,14 @@ static unsigned int snd_cmipci_pcm_pointer(cmipci_t *cm, cmipci_pcm_t *rec,
 	unsigned int ptr, reg;
 	spin_lock_irqsave(&cm->reg_lock, flags);
 	if (rec->running) {
+#if 1
+		reg = rec->ch ? CM_REG_CH1_FRAME2 : CM_REG_CH0_FRAME2;
+		ptr = rec->dma_size - (snd_cmipci_read_w(cm, reg) + 1);
+		ptr <<= sample_shift[rec->fmt]; /* convert to bytes */
+#else
 		reg = rec->ch ? CM_REG_CH1_FRAME1 : CM_REG_CH0_FRAME1;
 		ptr = snd_cmipci_read(cm, reg) - rec->offset;
+#endif
 	} else {
 		ptr = 0;
 	}
@@ -666,12 +679,10 @@ static void snd_cmipci_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 	if (status & CM_CHINT0) {
 		spin_lock(&cm->reg_lock);
 		snd_cmipci_clear_bit(cm, CM_REG_INT_HLDCLR, CM_CH0_INT_EN);
-		udelay(10);
 		snd_cmipci_set_bit(cm, CM_REG_INT_HLDCLR, CM_CH0_INT_EN);
 	}
 	if (status & CM_CHINT1) {
 		snd_cmipci_clear_bit(cm, CM_REG_INT_HLDCLR, CM_CH1_INT_EN);
-		udelay(10);
 		snd_cmipci_set_bit(cm, CM_REG_INT_HLDCLR, CM_CH1_INT_EN);
 	}
 	spin_unlock(&cm->reg_lock);
@@ -701,9 +712,7 @@ static void snd_cmipci_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 static void snd_cmipci_mixer_write(cmipci_t *s, unsigned char idx, unsigned char data)
 {
 	outb(idx, s->iobase + CM_REG_SB16_ADDR);
-	udelay(10);
 	outb(data, s->iobase + CM_REG_SB16_DATA);
-	udelay(10);
 }
 
 static unsigned char snd_cmipci_mixer_read(cmipci_t *s, unsigned char idx)
@@ -711,9 +720,7 @@ static unsigned char snd_cmipci_mixer_read(cmipci_t *s, unsigned char idx)
 	unsigned char v;
 
 	outb(idx, s->iobase + CM_REG_SB16_ADDR);
-	udelay(10);
 	v = inb(s->iobase + CM_REG_SB16_DATA);
-	udelay(10);
 	return v;
 }
 
@@ -1634,7 +1641,7 @@ static snd_pcm_hardware_t snd_cmipci_playback =
 	max_voices:	2,
 	min_fragment_size:	4096, // ??
 	max_fragment_size:	(128*1024),
-	fragment_align:	4096,
+	fragment_align:	4095,
 	fifo_size:	0,
 	transfer_block_size:	4,
 	ioctl:		snd_cmipci_playback_ioctl,
@@ -1657,7 +1664,7 @@ static snd_pcm_hardware_t snd_cmipci_capture =
 	max_voices:	2,
 	min_fragment_size:	64,
 	max_fragment_size:	(128*1024),
-	fragment_align:	32,
+	fragment_align:	31,
 	fifo_size:	0,
 	transfer_block_size:	4,
 	ioctl:		snd_cmipci_capture_ioctl,
@@ -1824,14 +1831,20 @@ static snd_kswitch_t snd_cmipci_switch_##sname = {\
 
 DEFINE_BIT_SWITCH(SND_CTL_SW_JOYSTICK, joy,
 		  CM_REG_FUNCTRL1, CM_JYSTK_EN, 0);
-DEFINE_BIT_SWITCH("SPDIF In", spdifin,
+DEFINE_BIT_SWITCH("SPDIF In Record", spdifin,
 		  CM_REG_FUNCTRL1, CM_SPDF_1, 0 );
 DEFINE_BIT_SWITCH("SPDIF Out", spdifout,
 		  CM_REG_LEGACY_CTRL, CM_ENSPDOUT|CM_SPDCOPYRHT|CM_DAC2SPDO, 0 );
+DEFINE_BIT_SWITCH("SPDIF Out 48KHz", spdo_48k,
+		  CM_REG_MISC_CTRL, CM_SPDF_AC97, 0 );
 DEFINE_BIT_SWITCH("SPDIF 5V", spdo5v,
 		  CM_REG_MISC_CTRL, CM_SPDO5V, 0 );
 DEFINE_BIT_SWITCH("SPDIF Loop", spdifloop,
 		  CM_REG_FUNCTRL1, CM_SPDFLOOP, 0);
+DEFINE_BIT_SWITCH("SPDIF In Monitor", spdimonitor,
+		  CM_REG_MIXER1, CM_CDPLAY, 1);
+DEFINE_BIT_SWITCH("SPDIF In Phase Inverse", spdiphase,
+		  CM_REG_MISC, 0x04, 0 );
 DEFINE_BIT_SWITCH("Four Channel", fourch,
 		  CM_REG_MISC_CTRL, CM_N4SPK3D, 0);
 DEFINE_BIT_SWITCH("Rear Out", rearout,
@@ -1843,8 +1856,11 @@ static void snd_cmipci_switches_new(cmipci_t *cm)
 	if (cm->card->type == SND_CARD_TYPE_CMI8738) {
 		snd_control_switch_new(cm->card, &snd_cmipci_switch_spdifin, cm);
 		snd_control_switch_new(cm->card, &snd_cmipci_switch_spdifout, cm);
+		snd_control_switch_new(cm->card, &snd_cmipci_switch_spdo_48k, cm);
 		snd_control_switch_new(cm->card, &snd_cmipci_switch_spdo5v, cm);
 		snd_control_switch_new(cm->card, &snd_cmipci_switch_spdifloop, cm);
+		snd_control_switch_new(cm->card, &snd_cmipci_switch_spdimonitor, cm);
+		snd_control_switch_new(cm->card, &snd_cmipci_switch_spdiphase, cm);
 		snd_control_switch_new(cm->card, &snd_cmipci_switch_fourch, cm);
 		snd_control_switch_new(cm->card, &snd_cmipci_switch_rearout, cm);
 	}
@@ -1911,11 +1927,15 @@ static void snd_cmipci_proc_done(cmipci_t *cm)
 #ifndef PCI_DEVICE_ID_CMEDIA_CM8738
 #define PCI_DEVICE_ID_CMEDIA_CM8738  0x0111
 #endif
+#ifndef PCI_DEVICE_ID_CMEDIA_CM8738B
+#define PCI_DEVICE_ID_CMEDIA_CM8738B 0x0112
+#endif
 
 static struct pci_device_id snd_cmipci_ids[] __devinitdata = {
 	{PCI_VENDOR_ID_CMEDIA, PCI_DEVICE_ID_CMEDIA_CM8338A, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0},
 	{PCI_VENDOR_ID_CMEDIA, PCI_DEVICE_ID_CMEDIA_CM8338B, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0},
 	{PCI_VENDOR_ID_CMEDIA, PCI_DEVICE_ID_CMEDIA_CM8738, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0},
+	{PCI_VENDOR_ID_CMEDIA, PCI_DEVICE_ID_CMEDIA_CM8738B, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0},
 	{0,},
 };
 
@@ -1985,6 +2005,20 @@ static int __init snd_cmipci_create(snd_card_t *card, snd_card_cmipci_t *scard,
 		default: val = CM_VMPU_330; break; /* 0x330 */
 		}
 		snd_cmipci_write(cm, CM_REG_LEGACY_CTRL, val);
+		/* enable UART */
+		snd_cmipci_set_bit(cm, CM_REG_FUNCTRL1, CM_UART_EN);
+	}
+
+	/* set FM address */
+	if (scard->enable_synth) {
+		val = snd_cmipci_read(cm, CM_REG_LEGACY_CTRL) & ~CM_FMSEL_MASK;
+		switch (cm->iosynth) {
+		case 0x3E8: val |= CM_FMSEL_3E8; break;
+		case 0x3E0: val |= CM_FMSEL_3E0; break;
+		case 0x3C8: val |= CM_FMSEL_3C8; break;
+		default: val |= CM_FMSEL_388; break; /* 0x388 */
+		}
+		snd_cmipci_write(cm, CM_REG_LEGACY_CTRL, val);
 	}
 
 	/* enable FM */
@@ -2127,7 +2161,7 @@ static int __init snd_cmipci_probe(struct pci_dev *pci,
 	if ((err = snd_cmipci_pcm_new(cm, 0, &pcm)) < 0)
 		goto __nodev;
 	if (scard->enable_midi) {
-		err = snd_mpu401_uart_new(card, 0, MPU401_HW_SB,
+		err = snd_mpu401_uart_new(card, 0, MPU401_HW_CMIPCI,
 					  cm->iomidi,
 					  cm->irqptr->irq, &rmidi);
 		if (err < 0)
