@@ -50,26 +50,34 @@ Card: EliteGroup P5TX-LA motherboard\n\
 Card: Dell Optiplex GX1\n\
 Card: Dell Workstation 400 Onboard\n\
 Card: Turtle Beach Malibu\n\
+Card: IBM Aptiva 2137 E24 Onboard\n\
 Card: Maxi Sound 16 PnP\n\
 Card: Gallant SC-70P\n\
 Card: NewClear 3D\n\
+ISAPNP: CSC0225=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC0437=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC0b35=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC1425=CSC0100,CSC0110\n\
 ISAPNP: CSC1525=CSC0100,CSC0110,CSC0103\n\
+ISAPNP: CSC1e37=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC4236=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC4237=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC4336=CSC0000,CSC0010,CSC0003\n\
+ISAPNP: CSC4536=CSC0000,CSC0010,CSC0003\n\
+ISAPNP: CSC4637=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC4837=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC6835=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC6836=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC7537=CSC0000,CSC0010,CSC0003\n\
+ISAPNP: CSC8025=CSC0100,CSC0110,CSC0103\n\
+ISAPNP: CSC8037=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC9836=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSC9837=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSCd925=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSCd937=CSC0000,CSC0010,CSC0003\n\
 ISAPNP: CSCe825=CSC0100,CSC0110\n\
 ISAPNP: CSCf235=CSC0000,CSC0010,CSC0003\n\
+ISAPNP: CSCf238=CSC0000,CSC0010,CSC0003\n\
 ");
 #endif
 
@@ -125,7 +133,7 @@ MODULE_PARM(snd_dma2_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_dma2_size, "Size of DMA2 # for " IDENT " driver. [DMA_SIZE]");
 #ifdef __ISAPNP__
 MODULE_PARM(snd_isapnp, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for specified soundcard. [BOOL]");
+MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for " IDENT " soundcard. [BOOL]");
 #endif
 
 static struct snd_card_cs4236 {
@@ -176,6 +184,11 @@ static unsigned int snd_card_pnpids[] = {
 #endif
 #ifdef CS4236
 static unsigned int snd_card_pnpids[] = {
+	/* Intel Marlin Spike Motherboard - CS4235 */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x0225),	  /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* Genius Sound Maker 3DJ - CS4237B */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x0437),   /* DEVICE */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
@@ -185,7 +198,7 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x0b35),   /* DEVICE */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
-	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */	
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* CS4235 on mainboard without MPU */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x1425),	  /* DEVICE */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0100), /* WSS */
@@ -196,6 +209,11 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0100), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0110), /* CTRL */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0103), /* MPU */
+	/* Crystal Computer TidalWave128 */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x1e37),	  /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* ACER AW37 - CS4235 */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x4236),   /* DEVICE */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
@@ -211,6 +229,16 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
+	/* Typhoon Soundsystem PnP - CS4236B */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x4536),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
+	/* Unknown - CS4237B */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x4637),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* NewClear 3D - CX4237B-XQ3 */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x4837),   /* DEVICE */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
@@ -231,6 +259,16 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
+	/* Onboard - CS4235 */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x8025),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0100), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0110), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0103), /* MPU */
+	/* IBM Aptiva 2137 E24 Onboard - CS4237B */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x8037),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* Maxi Sound 16 PnP - CS4236B */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0x9836),   /* DEVICE */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
@@ -261,6 +299,11 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
+	/* CS4236 */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0xf238),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* --- */
 	0	/* end */
 };
