@@ -147,7 +147,7 @@ static int __init snd_card_dt0197h_resources(int dev,
 					     snd_card_t *card)
 {
 	int error, shared_irq = 0;
-	static int no_alternatives[] = {-1};
+	static long no_alternatives[] = {-1};
 
 	if (snd_register_ioport(card, snd_mpu_port[dev], 2,
 			DRIVER_NAME" - MPU-401", NULL) < 0)
@@ -341,7 +341,7 @@ static int __init snd_card_dt0197h_probe(int dev, struct snd_card_dt0197h *acard
 
 	strcpy(card->abbreviation, "DT-0197H");
 	strcpy(card->shortname, "Diamond Tech. DT-0197H");
-	sprintf(card->longname, "%s soundcard, %s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s soundcard, %s at 0x%lx, irq %li, dma %li",
 		card->shortname, codec->name, codec->port,
 		acard->irqptr->irq, acard->dma8ptr->dma);
 	if (!snd_card_register(card)) {
