@@ -47,7 +47,7 @@ MODULE_PARM_DESC(snd_index, "Index value for dummy soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
 MODULE_PARM_DESC(snd_id, "ID string for dummy soundcard.");
 MODULE_PARM(snd_enable, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_enable, "Enable this dummy soundcard. [BOOL]");
+MODULE_PARM_DESC(snd_enable, "Enable this soundcard. [BOOL]");
 MODULE_PARM(snd_mixer_devs, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_mixer_devs, "Mixer devices # (0-1) for dummy driver. [range=0-1]");
 MODULE_PARM(snd_pcm_devs, "1-" __MODULE_STRING(SND_CARDS) "i");
