@@ -25,6 +25,8 @@
 #include "../include/initval.h"
 
 #ifndef CHIP1371
+#define CARD_NAME "Ensoniq AudioPCI ENS1370"
+#define DRIVER_NAME "ENS1370"
 #undef CHIP1370
 #define CHIP1370
 #endif
@@ -56,15 +58,15 @@ int snd_dac1_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 int snd_dac2_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 int snd_adc_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_index, "Index value for Ensoniq AudioPCI soundcard.");
+MODULE_PARM_DESC(snd_index, "Index value for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
-MODULE_PARM_DESC(snd_id, "ID string for Ensoniq AudioPCI soundcard.");
+MODULE_PARM_DESC(snd_id, "ID string for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_dac1_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dac1_frame_size, "DAC1 frame size in kB for Ensoniq AudioPCI soundcard.");
+MODULE_PARM_DESC(snd_dac1_frame_size, "DAC1 frame size in kB for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_dac2_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dac2_frame_size, "DAC2 frame size in kB for Ensoniq AudioPCI soundcard.");
+MODULE_PARM_DESC(snd_dac2_frame_size, "DAC2 frame size in kB for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_adc_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_adc_frame_size, "ADC frame size in kB for Ensoniq AudioPCI soundcard.");
+MODULE_PARM_DESC(snd_adc_frame_size, "ADC frame size in kB for " CARD_NAME " soundcard.");
 
 #ifdef CHIP1370
 #define snd_ensoniq_interrupt snd_ensoniq_1370_interrupt
@@ -204,6 +206,10 @@ static int __init snd_audiopci_probe(int dev, struct snd_audiopci *scard)
 		snd_card_free(card);
 		return -ENODEV;
 	}
+	if (pci_enable_device(scard->pci)) {
+		snd_card_free(card);
+		return -ENODEV;
+	}
 	if (snd_audiopci_resources(card, scard, dev) < 0) {
 		snd_card_free(card);
 		return -ENODEV;
@@ -224,7 +230,7 @@ static int __init snd_audiopci_probe(int dev, struct snd_audiopci *scard)
 		goto __nodev;
 	strcpy(card->abbreviation, "AudioPCI");
 	strcpy(card->shortname, "Ensoniq AudioPCI");
-	sprintf(card->longname, "%s %s at 0x%lx, irq %i",
+	sprintf(card->longname, "%s %s at 0x%lx, irq %li",
 		card->shortname,
 		card->type == SND_CARD_TYPE_ENS1370 ? "ES1370" : "ES1371",
 		pci_resource_start(scard->pci, 0),
