@@ -273,8 +273,8 @@ static int __init snd_audiodrive_resources(int dev,
 					   struct snd_audiodrive *acard,
 					   snd_card_t * card)
 {
-	static int possible_irqs[] = {5, 9, 10, 7, 11, 12, -1};
-	static int possible_dmas[] = {1, 0, 3, 5, -1};
+	static long possible_irqs[] = {5, 9, 10, 7, 11, 12, -1};
+	static long possible_dmas[] = {1, 0, 3, 5, -1};
 	int err;
 
 	if((err = snd_register_interrupt(card, "ES18xx",
@@ -459,7 +459,7 @@ static int __init snd_audiodrive_probe(int dev, struct snd_audiodrive *acard)
 	}
 	sprintf(card->abbreviation, "ES%x", codec->version);
 	sprintf(card->shortname, "ESS AudioDrive ES%x", codec->version);
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma1 %i, dma2 %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma1 %li, dma2 %li",
 		card->shortname,
 		codec->port,
 		acard->irqptr->irq,
