@@ -175,7 +175,7 @@ static int __init snd_solo_probe(int dev, struct snd_solo *scard)
 
 	strcpy(card->abbreviation, "Solo-1");
 	strcpy(card->shortname, "ESS Solo-1");
-	sprintf(card->longname, "%s rev %i, irq %i",
+	sprintf(card->longname, "%s rev %i, irq %li",
 		card->shortname,
 		scard->solo->revision,
 		scard->irqptr->irq);
