@@ -171,8 +171,8 @@ static void snd_gusclassic_interrupt(int irq, void *dev_id, struct pt_regs *regs
 static int __init snd_gusclassic_resources(int dev, struct snd_gusclassic *guscard,
 					   snd_card_t * card)
 {
-	static int possible_irqs[] = {5, 11, 12, 9, 7, 15, 3, 4, -1};
-	static int possible_dmas[] = {5, 6, 7, 1, 3, -1};
+	static long possible_irqs[] = {5, 11, 12, 9, 7, 15, 3, 4, -1};
+	static long possible_dmas[] = {5, 6, 7, 1, 3, -1};
 	int err;
 
 	if ((err = snd_register_interrupt(card, "GUS Classic",
@@ -283,12 +283,12 @@ static int __init snd_gusclassic_probe(int dev, struct snd_gusclassic *guscard)
 	if (snd_gus_attach_synthesizer(gus) < 0)
 		goto __nodev;
 #endif
-	sprintf(card->longname + strlen(card->longname), " at 0x%x, irq %i, dma %i",
+	sprintf(card->longname + strlen(card->longname), " at 0x%lx, irq %li, dma %li",
 		gus->gf1.port,
 		guscard->irqptr->irq,
 		guscard->dma1ptr->dma);
 	if (guscard->dma2ptr)
-		sprintf(card->longname + strlen(card->longname), "&%i",
+		sprintf(card->longname + strlen(card->longname), "&%li",
 			guscard->dma2ptr->dma);
 	snd_gf1_start(gus);
 	if (!snd_card_register(card)) {
