@@ -263,10 +263,10 @@ static void snd_gusextreme_ess_midi_interrupt(int irq, void *dev_id, struct pt_r
 
 static int __init snd_gusextreme_resources(int dev, struct snd_gusextreme *acard, snd_card_t * card)
 {
-	static int possible_irqs[] = {5, 9, 10, 7, -1};
-	static int possible_dmas[] = {1, 3, 0, -1};
-	static int possible_irqs1[] = {5, 11, 12, 9, 7, 15, 3, -1};
-	static int possible_dmas1[] = {5, 6, 7, 1, 3, -1};
+	static long possible_irqs[] = {5, 9, 10, 7, -1};
+	static long possible_dmas[] = {1, 3, 0, -1};
+	static long possible_irqs1[] = {5, 11, 12, 9, 7, 15, 3, -1};
+	static long possible_dmas1[] = {5, 6, 7, 1, 3, -1};
 	int err;
 
 	if ((err = snd_register_interrupt(card,
@@ -417,7 +417,7 @@ static int __init snd_gusextreme_probe(int dev, struct snd_gusextreme *acard)
 	if (snd_gus_attach_synthesizer(gus) < 0)
 		goto __nodev;
 #endif
-	sprintf(card->longname, "Gravis UltraSound Extreme at 0x%x, irq %i&%i, dma %i&%i",
+	sprintf(card->longname, "Gravis UltraSound Extreme at 0x%lx, irq %li&%li, dma %li&%li",
 		codec->port,
 		acard->irqptr->irq,
 		acard->irq1ptr->irq,
