@@ -29,9 +29,10 @@
 #include "../include/initval.h"
 
 MODULE_DESCRIPTION("\
-Driver: Intel 82801AA,82901AB,i810,i820,i830,i840,MX440\n\
+Driver: Intel 82801AA,82801BA,82901AB,i810,i815,i820,i830,i840,MX440\n\
 PCI: 0x8086=0x2415\n\
 PCI: 0x8086=0x2425\n\
+PCI: 0x8086=0x2445\n\
 PCI: 0x8086=0x7195\n\
 ");
 
@@ -40,6 +41,7 @@ char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
 int snd_pbk_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 int snd_cap_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 int snd_mic_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
+int snd_ac97_clock[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 48000};
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_index, "Index value for Intel i8x0 soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
@@ -51,6 +53,8 @@ MODULE_PARM(snd_cap_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_cap_frame_size, "Capture frame size in kB.");
 MODULE_PARM(snd_mic_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_mic_frame_size, "MIC capture frame size in kB.");
+MODULE_PARM(snd_ac97_clock, "1-" __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM_DESC(snd_ac97_clock, "AC'97 codec clock (default 48000Hz).");
 
 typedef struct snd_intel8x0_card {
 	struct pci_dev *pci;
@@ -147,6 +151,12 @@ static int __init snd_intel8x0_probe(int dev, intel8x0_card_t *scard)
 		if (!snd_intel8x0_detect(card, scard, PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_82801))
 			break;
 	} while (scard->pci);
+	if (scard->pci != NULL)
+		goto __found;
+	do {
+		if (!snd_intel8x0_detect(card, scard, PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_82801BA))
+			break;
+	} while (scard->pci);
 	if (scard->pci != NULL)
 		goto __found;
 	do {
@@ -179,6 +189,7 @@ static int __init snd_intel8x0_probe(int dev, intel8x0_card_t *scard)
 			       scard->dma_cap,
 			       scard->dma_mic,
 			       scard->irqptr,
+			       snd_ac97_clock[dev],
 			       &scard->codec) < 0)
 		goto __nodev;
 	codec = scard->codec;
@@ -199,6 +210,9 @@ static int __init snd_intel8x0_probe(int dev, intel8x0_card_t *scard)
 	case PCI_DEVICE_ID_INTEL_82801:
 		strcpy(card->shortname, "Intel ICH 82801AA");
 		break;
+	case PCI_DEVICE_ID_INTEL_82801BA:
+		strcpy(card->shortname, "Intel ICH 82801BA");
+		break;
 	case PCI_DEVICE_ID_INTEL_82901:
 		strcpy(card->shortname, "Intel ICH 82901AB");
 		break;
