@@ -32,6 +32,11 @@
 #endif
 #include "../include/initval.h"
 
+#ifndef CARD_NAME
+#define CARD_NAME "InterWave"
+#define DRIVER_NAME "InterWave"
+#endif
+
 #ifndef SND_STB
 MODULE_DESCRIPTION("\
 Driver: AMD InterWave\n\
@@ -74,37 +79,37 @@ int snd_midi[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0};
 int snd_pcm_voices[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 2};
 int snd_effect[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0};
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_index, "Index value for InterWave soundcard.");
+MODULE_PARM_DESC(snd_index, "Index value for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
-MODULE_PARM_DESC(snd_id, "ID string for InterWave soundcard.");
+MODULE_PARM_DESC(snd_id, "ID string for " CARD_NAME " soundcard.");
 #ifdef __ISAPNP__
 MODULE_PARM(snd_isapnp, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for specified soundcard. [BOOL]");
+MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for " CARD_NAME " soundcard. [BOOL]");
 #endif
 MODULE_PARM(snd_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_port, "Port # for InterWave driver. [list=0x210,0x220,0x230,0x240,0x250,0x260]");
+MODULE_PARM_DESC(snd_port, "Port # for " DRIVER_NAME " driver. [list=0x210,0x220,0x230,0x240,0x250,0x260]");
 #ifdef SND_STB
 MODULE_PARM(snd_port_tc, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_port_tc, "Tone control (TEA6330T - i2c bus) port # for InterWave driver. [list=0x350,0x360,0x370,0x380]");
+MODULE_PARM_DESC(snd_port_tc, "Tone control (TEA6330T - i2c bus) port # for " DRIVER_NAME " driver. [list=0x350,0x360,0x370,0x380]");
 #endif
 MODULE_PARM(snd_irq, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_irq, "IRQ # for InterWave driver. [list=3,5,9,11,12,15]");
+MODULE_PARM_DESC(snd_irq, "IRQ # for " DRIVER_NAME " driver. [list=3,5,9,11,12,15]");
 MODULE_PARM(snd_dma1, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma1, "DMA1 # for InterWave driver. [list=0,1,3,5,6,7]");
+MODULE_PARM_DESC(snd_dma1, "DMA1 # for " DRIVER_NAME " driver. [list=0,1,3,5,6,7]");
 MODULE_PARM(snd_dma2, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma2, "DMA2 # for InterWave driver. [list=0,1,3,5,6,7]");
+MODULE_PARM_DESC(snd_dma2, "DMA2 # for " DRIVER_NAME " driver. [list=0,1,3,5,6,7]");
 MODULE_PARM(snd_dma1_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma1_size, "DMA1 size in kB for InterWave driver. [DMA_SIZE]");
+MODULE_PARM_DESC(snd_dma1_size, "DMA1 size in kB for " DRIVER_NAME " driver. [DMA_SIZE]");
 MODULE_PARM(snd_dma2_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma2_size, "DMA2 size in kB for InterWave driver. [DMA_SIZE]");
+MODULE_PARM_DESC(snd_dma2_size, "DMA2 size in kB for " DRIVER_NAME " driver. [DMA_SIZE]");
 MODULE_PARM(snd_joystick_dac, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_joystick_dac, "Joystick DAC level 0.59V-4.52V or 0.389V-2.98V for InterWave driver. [range=0-31]");
+MODULE_PARM_DESC(snd_joystick_dac, "Joystick DAC level 0.59V-4.52V or 0.389V-2.98V for " DRIVER_NAME " driver. [range=0-31]");
 MODULE_PARM(snd_midi, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_midi, "MIDI UART enable for InterWave driver. [BOOL]");
+MODULE_PARM_DESC(snd_midi, "Enable MIDI MPU-401 for " DRIVER_NAME " driver. [BOOL]");
 MODULE_PARM(snd_pcm_voices, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_pcm_voices, "Reserved PCM voices for InterWave driver. [range=2-16]");
+MODULE_PARM_DESC(snd_pcm_voices, "Reserved PCM voices for " DRIVER_NAME " driver. [range=2-16]");
 MODULE_PARM(snd_effect, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_effect, "Effects enable for InterWave driver. [BOOL]");
+MODULE_PARM_DESC(snd_effect, "Effects enable for " DRIVER_NAME " driver. [BOOL]");
 
 struct snd_interwave {
 	snd_irq_t *irqptr;
