@@ -299,11 +299,11 @@ static void snd_mozart_interrupt1(int irq, void *dev_id, struct pt_regs *regs)
 
 static int __init snd_mozart_resources(void)
 {
-	static int possible_irqs[] = {9, 10, 11, 7, -1};
+	static long possible_irqs[] = {9, 10, 11, 7, -1};
 #ifdef MOZART_SB_MIDI
-	static int possible_irqs1[] = {11, 5, 7, -1};
+	static long possible_irqs1[] = {11, 5, 7, -1};
 #endif
-	static int possible_dmas[] = {1, 3, 0, -1};
+	static long possible_dmas[] = {1, 3, 0, -1};
 	int err;
 
 	if ((err = snd_register_interrupt(snd_card, "Mozart",
@@ -381,7 +381,7 @@ static int __init snd_mozart_probe(void)
 
 	strcpy(snd_card->abbreviation, "OAK Mozart");
 	strcpy(snd_card->shortname, "OAK Mozart");
-	sprintf(snd_card->longname, "OAK Mozart at 0x%x, irq %i, dma %i",
+	sprintf(snd_card->longname, "OAK Mozart at 0x%x, irq %li, dma %li",
 		snd_port,
 		snd_irqptr->irq,
 		snd_dma1ptr->dma);
