@@ -91,9 +91,13 @@ MODULE_PARM(snd_mpu_irq, "i");
 MODULE_PARM_DESC(snd_mpu_irq, "MPU-401 irq # for opti9xx driver. [IRQ]");
 MODULE_PARM(snd_dma1, "i");
 MODULE_PARM_DESC(snd_dma1, "1st dma # for opti9xx driver. [DMA8]");
+MODULE_PARM(snd_dma1_size, "i");
+MODULE_PARM_DESC(snd_dma1_size, "Size of 1st dma for opti9xx driver. [DMA8_SIZE]");
 #if defined(CS4231) || defined(OPTi93X)
 MODULE_PARM(snd_dma2, "i");
 MODULE_PARM_DESC(snd_dma2, "2nd dma # for opti9xx driver. [DMA8]");
+MODULE_PARM(snd_dma2_size, "i");
+MODULE_PARM_DESC(snd_dma2_size, "Size of 2nd dma for opti9xx driver. [DMA8_SIZE]");
 #endif	/* CS4231 || OPTi93X */
 
 
@@ -301,7 +305,7 @@ __again:
 	if (snd_port != SND_AUTO_PORT)
 		isapnp_resource_change(&pdev->resource[0], snd_port + 4, 4);
 #else
-	if ((hw != 0x0924) && (snd_port != SND_AUTO_PORT))
+	if ((hw != ISAPNP_DEVICE(0x0924)) && (snd_port != SND_AUTO_PORT))
 		isapnp_resource_change(&pdev->resource[1], snd_port, 4);
 #endif	/* OPTi93X */
 	if (snd_irq != SND_AUTO_IRQ)
@@ -324,7 +328,7 @@ __again:
 	snd_port = pdev->resource[0].start - 4;
 	snd_fm_port = pdev->resource[1].start;
 #else
-	if (hw != 0x0924)
+	if (hw != ISAPNP_DEVICE(0x0924))
 		snd_port = pdev->resource[1].start;
 	snd_fm_port = pdev->resource[2].start;
 #endif	/* OPTi93X */
@@ -370,18 +374,18 @@ static int __init snd_card_opti9xx_resources(struct snd_card_opti9xx *acard,
 					     snd_card_t *card)
 {
 	int error, i, pnp = 0;
-	static int no_alternatives[] = {-1};
-	static int possible_ports[] = {0x530, 0xe80, 0xf40, 0x604, -1};
-	static int possible_mpu_ports[] = {0x300, 0x310, 0x320, 0x330, -1};
+	static long no_alternatives[] = {-1};
+	static long possible_ports[] = {0x530, 0xe80, 0xf40, 0x604, -1};
+	static long possible_mpu_ports[] = {0x300, 0x310, 0x320, 0x330, -1};
 #ifdef OPTi93X
-	static int possible_irqs[] = {5, 9, 10, 11, 7, -1};
+	static long possible_irqs[] = {5, 9, 10, 11, 7, -1};
 #else
-	static int possible_irqs[] = {9, 10, 11, 7, -1};
+	static long possible_irqs[] = {9, 10, 11, 7, -1};
 #endif	/* OPTi93X */
-	static int possible_mpu_irqs[] = {5, 9, 10, 7, -1};
-	static int possible_dma1s[] = {3, 1, 0, -1};
+	static long possible_mpu_irqs[] = {5, 9, 10, 7, -1};
+	static long possible_dma1s[] = {3, 1, 0, -1};
 #if defined(CS4231) || defined(OPTi93X)
-	static int possible_dma2s[][2] = {{1,-1}, {0,-1}, {-1,-1}, {0,-1}};
+	static long possible_dma2s[][2] = {{1,-1}, {0,-1}, {-1,-1}, {0,-1}};
 #endif	/* CS4231 || OPTi93X */
 
 #ifdef __ISAPNP__
@@ -566,7 +570,7 @@ static int __init snd_card_opti9xx_probe(struct snd_card_opti9xx *acard)
 		if ((error = snd_mpu401_uart_new(card, 0, MPU401_HW_MPU401,
 				acard->chip->mpu_port, acard->chip->mpu_irq,
 				&rmidi)))
-			snd_card_opti9xx_printk("no MPU-401 device at 0x%x?\n",
+			snd_card_opti9xx_printk("no MPU-401 device at 0x%lx?\n",
 				acard->chip->mpu_port);
 
 	if (acard->chip->fm_port <= 0)
@@ -579,17 +583,17 @@ static int __init snd_card_opti9xx_probe(struct snd_card_opti9xx *acard)
 #else
 				OPL3_HW_AUTO, 0, &synth)))
 #endif	/* CS4231 */
-			snd_card_opti9xx_printk("no OPL device at 0x%x-0x%x?\n",
+			snd_card_opti9xx_printk("no OPL device at 0x%lx-0x%lx?\n",
 				acard->chip->fm_port, acard->chip->fm_port + 2);
 
 	strcpy(card->abbreviation, acard->chip->name);
 	sprintf(card->shortname, "OPTi %s", card->abbreviation);
 #if defined(CS4231) || defined(OPTi93X)
-	sprintf(card->longname, "%s soundcard, %s at 0x%x, irq %i, dma %i&%i",
+	sprintf(card->longname, "%s soundcard, %s at 0x%lx, irq %li, dma %li&%li",
 		card->shortname, pcm->name, acard->chip->wss_base + 4,
 		acard->irqptr->irq, acard->dma1ptr->dma, acard->dma2ptr->dma);
 #else
-	sprintf(card->longname, "%s soundcard, %s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s soundcard, %s at 0x%lx, irq %li, dma %li",
 		card->shortname, pcm->name, acard->chip->wss_base + 4,
 		acard->irqptr->irq, acard->dma1ptr->dma);
 #endif	/* CS4231 || OPTi93X */
