@@ -157,6 +157,9 @@ static int snd_rme9652_probe(int dev, rme9652_t *rme9652,
 		return -EMFILE; 
 	}
 
+	if (pci_enable_device(*pci_info))
+		goto __nodev;
+
 	if ((err = snd_register_interrupt (card,
 					   rme9652->card_name,
 					   rme9652->pci->irq,
@@ -175,7 +178,7 @@ static int snd_rme9652_probe(int dev, rme9652_t *rme9652,
 	strcpy(card->abbreviation, "Hammerfall");
 	strcpy(card->shortname, rme9652->card_name);
 
-	sprintf(card->longname, "%s at 0x%lx, irq %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li",
 		card->shortname,
 		rme9652->port,
 		rme9652->irqptr->irq);
