@@ -29,6 +29,11 @@
 #include "../include/emu8000.h"
 #include "../include/seq_device.h"
 
+#ifndef CARD_NAME
+#define CARD_NAME	"Sound Blaster 16"
+#define DRIVER_NAME	"SB16"
+#endif
+
 #ifndef SND_SBAWE
 MODULE_DESCRIPTION("\
 Driver: Sound Blaster 16\n\
@@ -56,15 +61,18 @@ ISAPNP: CTL0044=CTL0031,CTL0021\n\
 ISAPNP: CTL0047=CTL0031,CTL0021\n\
 ISAPNP: CTL0048=CTL0031,CTL0021\n\
 ISAPNP: CTL0054=CTL0031,CTL0021\n\
+ISAPNP: CTL009a=CTL0041,CTL0021\n\
 ISAPNP: CTL009c=CTL0041,CTL0021\n\
 ISAPNP: CTL009d=CTL0042,CTL0022\n\
 ISAPNP: CTL009e=CTL0044,CTL0023\n\
+ISAPNP: CTL009f=CTL0041,CTL0021\n\
 ISAPNP: CTL00b2=CTL0044,CTL0023\n\
 ISAPNP: CTL00c1=CTL0042,CTL0022\n\
 ISAPNP: CTL00c3=CTL0045,CTL0022\n\
 ISAPNP: CTL00c5=CTL0045,CTL0022\n\
 ISAPNP: CTL00c7=CTL0045,CTL0022\n\
 ISAPNP: CTL00e4=CTL0045,CTL0022\n\
+ISAPNP: CTL00ed=CTL0041,CTL0070\n\
 ");
 #endif
 
@@ -100,29 +108,29 @@ int snd_isapnp[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 1};
 int snd_seq_ports[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 4};
 #endif
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_index, "Index value for SoundBlaster 16 soundcard.");
+MODULE_PARM_DESC(snd_index, "Index value for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
-MODULE_PARM_DESC(snd_id, "ID string for SoundBlaster 16 soundcard.");
+MODULE_PARM_DESC(snd_id, "ID string for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_port, "Port # for SB16 driver. [list=0x220,0x240,0x260]");
+MODULE_PARM_DESC(snd_port, "Port # for " DRIVER_NAME " driver. [list=0x220,0x240,0x260]");
 MODULE_PARM(snd_mpu_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_mpu_port, "MPU-401 port # for SB16 driver. [list=0x330,0x300]");
+MODULE_PARM_DESC(snd_mpu_port, "MPU-401 port # for " DRIVER_NAME " driver. [list=0x330,0x300]");
 MODULE_PARM(snd_fm_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_fm_port, "FM port # for SB16 driver. [list=0x388]");
+MODULE_PARM_DESC(snd_fm_port, "FM port # for " DRIVER_NAME " driver. [list=0x388]");
 #ifdef SND_SBAWE_EMU8000
 MODULE_PARM(snd_awe_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_awe_port, "AWE port # for SB16 driver. [list=0x620]");
+MODULE_PARM_DESC(snd_awe_port, "AWE port # for " DRIVER_NAME " driver. [list=0x620]");
 #endif
 MODULE_PARM(snd_irq, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_irq, "IRQ # for SB16 driver. [IRQ]");
+MODULE_PARM_DESC(snd_irq, "IRQ # for " DRIVER_NAME " driver. [IRQ]");
 MODULE_PARM(snd_dma8, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma8, "8-bit DMA # for SB16 driver. [DMA8]");
+MODULE_PARM_DESC(snd_dma8, "8-bit DMA # for " DRIVER_NAME " driver. [DMA8]");
 MODULE_PARM(snd_dma16, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma16, "16-bit DMA # for SB16 driver. [DMA16]");
+MODULE_PARM_DESC(snd_dma16, "16-bit DMA # for " DRIVER_NAME " driver. [DMA16]");
 MODULE_PARM(snd_dma8_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma8_size, "Size of 8-bit DMA # for SB16 driver. [DMA8_SIZE]");
+MODULE_PARM_DESC(snd_dma8_size, "Size of 8-bit DMA # for " DRIVER_NAME " driver. [DMA8_SIZE]");
 MODULE_PARM(snd_dma16_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dma16_size, "Size of 16-bit DMA # for SB16 driver. [DMA16_SIZE]");
+MODULE_PARM_DESC(snd_dma16_size, "Size of 16-bit DMA # for " DRIVER_NAME " driver. [DMA16_SIZE]");
 MODULE_PARM(snd_mic_agc, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_mic_agc, "Mic Auto-Gain-Control switch. [BOOL]");
 #ifdef CONFIG_SND_SB16_CSP
@@ -131,7 +139,7 @@ MODULE_PARM_DESC(snd_csp, "ASP/CSP chip support. [BOOL]");
 #endif
 #ifdef __ISAPNP__
 MODULE_PARM(snd_isapnp, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for specified soundcard. [BOOL]");
+MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for " CARD_NAME " soundcard. [BOOL]");
 #endif
 #ifdef SND_SBAWE_EMU8000
 MODULE_PARM(snd_seq_ports, "1-" __MODULE_STRING(SND_CARDS) "i");
@@ -241,6 +249,12 @@ static unsigned int snd_sb16_pnpids[] = {
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
 #ifdef SND_SBAWE_EMU8000
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0021), /* WaveTable */
+#endif
+	/* Sound Blaster AWE 32 PnP */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x009a),   /* DEVICE */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0041), /* Audio */
+#ifdef SND_SBAWE_EMU8000
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0021), /* WaveTable */
 #endif
 	/* Sound Blaster AWE 32 PnP */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x009c),   /* DEVICE */
@@ -259,6 +273,12 @@ static unsigned int snd_sb16_pnpids[] = {
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0044), /* Audio */
 #ifdef SND_SBAWE_EMU8000
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0023), /* WaveTable */
+#endif
+	/* Sound Blaster 32 PnP */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x009f),   /* DEVICE */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0041), /* Audio */
+#ifdef SND_SBAWE_EMU8000
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0021), /* WaveTable */
 #endif
 	/* Sound Blaster AWE 64 PnP Gold */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x00b2),   /* DEVICE */
@@ -295,6 +315,12 @@ static unsigned int snd_sb16_pnpids[] = {
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0045), /* Audio */
 #ifdef SND_SBAWE_EMU8000
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0022), /* WaveTable */
+#endif
+	/* Sound Blaster 16 PnP (AWE) */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x00ed),   /* DEVICE */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0041), /* Audio */
+#ifdef SND_SBAWE_EMU8000
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0070), /* WaveTable */
 #endif
 	/* --- */
 	0       /* end */
@@ -323,26 +349,26 @@ static snd_pcm_t * __init snd_sb16_detect(int dev,
 	sbdsp_t *codec;
 	int mpu_flag = 0, err;
 
-	if (snd_register_ioport(card, port, 16, "Sound Blaster 16", NULL) < 0)
+	if (snd_register_ioport(card, port, 16, CARD_NAME, NULL) < 0)
 		return NULL;
 	if (snd_mpu_port[dev] == 0x300 || snd_mpu_port[dev] == 0x330) {
 		if (snd_register_ioport(card, snd_mpu_port[dev], 2,
-					"Sound Blaster 16 - MPU-401", NULL) < 0) {
+					CARD_NAME " - MPU-401", NULL) < 0) {
 			snd_printk("sb16: port 0x%x isn't free for MPU-401, midi port is disabled\n", snd_mpu_port[dev]);
 		} else {
 			mpu_flag = 1;
 		}
 	}
 	if (snd_fm_port[dev] >= 0x300 && snd_fm_port[dev] < 0x400)
-		snd_register_ioport(card, snd_fm_port[dev], 4, "Sound Blaster 16 - FM", NULL);
+		snd_register_ioport(card, snd_fm_port[dev], 4, CARD_NAME " - FM", NULL);
 #ifdef SND_SBAWE_EMU8000
 	if (snd_awe_port[dev] >= 0x620 && snd_awe_port[dev] < 0x6a0) {
 		if (snd_register_ioport(card, snd_awe_port[dev],
-					4, "Sound Blaster AWE", NULL) < 0 ||
+					4, CARD_NAME " - WaveTable", NULL) < 0 ||
 		    snd_register_ioport(card, snd_awe_port[dev] + (0xa40 - 0x640),
-		    			4, "Sound Blaster AWE", NULL) < 0 ||
+		    			4, CARD_NAME " - WaveTable", NULL) < 0 ||
 		    snd_register_ioport(card, snd_awe_port[dev] + (0xe40 - 0x640),
-		    			4, "Sound Blaster AWE", NULL) < 0) {
+		    			4, CARD_NAME " - WaveTable", NULL) < 0) {
 			snd_printk("sb16: EMU8000 ports aren't available\n");
 			snd_unregister_ioports(card);
 			return NULL;
@@ -415,14 +441,14 @@ static int __init snd_sb16_resources(int dev, struct snd_sb16 *acard,
 	int err, ok = 0;
 
 	if ((err = snd_register_interrupt(card,
-			"Sound Blaster 16", snd_irq[dev],
+			CARD_NAME, snd_irq[dev],
 			SND_IRQ_TYPE_ISA, snd_sb16_interrupt,
 			acard, possible_irqs, &acard->irqptr)) < 0)
 		return err;
 	if ((snd_dma8[dev] >= 0 && snd_dma8[dev] <= 3) ||
 	    snd_dma8[dev] == SND_AUTO_DMA) {
 		if ((err = snd_register_dma_channel(card,
-				"Sound Blaster 16", snd_dma8[dev],
+				CARD_NAME, snd_dma8[dev],
 				SND_DMA_TYPE_ISA, snd_dma8_size[dev],
 				possible_dmas8, &acard->dma8ptr)) < 0)
 			return err;
@@ -433,7 +459,7 @@ static int __init snd_sb16_resources(int dev, struct snd_sb16 *acard,
 	if ((snd_dma16[dev] >= 4 && snd_dma16[dev] <= 7) ||
 	    snd_dma16[dev] == SND_AUTO_DMA) {
 		if ((err = snd_register_dma_channel(card,
-				"Sound Blaster 16", snd_dma16[dev],
+				CARD_NAME, snd_dma16[dev],
 				SND_DMA_TYPE_ISA, snd_dma16_size[dev],
 				possible_dmas16, &acard->dma16ptr)) < 0)
 			return err;
@@ -684,8 +710,8 @@ static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 		(snd_mic_agc[dev] ? 0x00 : 0x01));
 	spin_unlock_irqrestore(&codec->mixer.lock, flags);
 
-	strcpy(card->abbreviation, "SB16");
-	strcpy(card->shortname, "Sound Blaster 16");
+	strcpy(card->abbreviation, DRIVER_NAME);
+	strcpy(card->shortname, CARD_NAME);
 	sprintf(card->longname, "%s at 0x%lx, irq %li, dma ",
 		codec->name,
 		codec->port,
@@ -756,7 +782,7 @@ static int __init alsa_card_sb16_init(void)
 			if (snd_port[dev] == SND_AUTO_PORT)
 				break;
 #ifdef MODULE
-			snd_printk("Sound Blaster 16 soundcard #%i not found at 0x%x or device busy\n", dev + 1, snd_port[dev]);
+			snd_printk(CARD_NAME " soundcard #%i not found at 0x%x or device busy\n", dev + 1, snd_port[dev]);
 #endif
 			continue;
 		}
@@ -765,7 +791,7 @@ static int __init alsa_card_sb16_init(void)
 	}
 	if (!cards) {
 #ifdef MODULE
-		snd_printk("Sound Blaster 16 soundcard #%i not found or device busy\n", dev + 1);
+		snd_printk(CARD_NAME " soundcard #%i not found or device busy\n", dev + 1);
 #endif
 		return -ENODEV;
 	}
