@@ -122,8 +122,8 @@ static void snd_sb8_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 
 static int __init snd_sb8_resources(int dev, struct snd_sb8 *acard, snd_card_t * card)
 {
-	static int possible_irqs[] = {-1};
-	static int possible_dmas8[] = {-1};
+	static long possible_irqs[] = {-1};
+	static long possible_dmas8[] = {-1};
 	int err;
 
 	if ((err = snd_register_interrupt(card,
@@ -201,7 +201,7 @@ static int __init snd_sb8_probe(int dev, struct snd_sb8 *acard)
 		str++;
 	if (*str == '(' && str != card->shortname)
 		*(str - 1) = 0;
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma %li",
 		codec->name,
 		codec->port,
 		acard->irqptr->irq,
