@@ -37,7 +37,7 @@ PCI: 0x1106=0x3058\n\
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
 int snd_mpu_port[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = -1};
-int snd_joystick[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = -1};
+int snd_joystick[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0};
 int snd_pbk_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 int snd_cap_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 int snd_fm_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
@@ -54,6 +54,8 @@ MODULE_PARM(snd_cap_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_cap_frame_size, "Capture frame size in kB.");
 MODULE_PARM(snd_fm_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_fm_frame_size, "FM playback frame size in kB.");
+MODULE_PARM(snd_joystick, "1-" __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM_DESC(snd_joystick, "Joystick support. [BOOL]");
 
 /*
  *  Direct registers
@@ -149,7 +151,7 @@ struct snd_stru_via686a {
 	snd_dma_t * dma_fm;	/* FM playback */
 	snd_irq_t * irqptr;
 
-	unsigned int port;
+	unsigned long port;
 	unsigned char revision;
 
 	struct pci_dev *pci;
@@ -275,9 +277,9 @@ static unsigned short snd_via686a_codec_read(void *private_data,
 #if 0
 static void snd_via686a_channel_print(via686a_t *codec, viadev_t *viadev)
 {
-	unsigned int port = codec->port + viadev->reg_offset;
+	unsigned long port = codec->port + viadev->reg_offset;
 
-	printk("[0x%x] status = 0x%x, control = 0x%x, type = 0x%x, ptr = 0x%x, count = 0x%x\n",
+	printk("[0x%lx] status = 0x%x, control = 0x%x, type = 0x%x, ptr = 0x%x, count = 0x%x\n",
 			port,
 			inb(port + VIA_REG_OFFSET_STATUS),
 			inb(port + VIA_REG_OFFSET_CONTROL),
@@ -289,7 +291,7 @@ static void snd_via686a_channel_print(via686a_t *codec, viadev_t *viadev)
 
 static void snd_via686a_channel_reset(via686a_t *codec, viadev_t *viadev)
 {
-	unsigned int port = codec->port + viadev->reg_offset;
+	unsigned long port = codec->port + viadev->reg_offset;
 
 	outb(VIA_REG_CTRL_PAUSE | VIA_REG_CTRL_TERMINATE | VIA_REG_CTRL_RESET, port + VIA_REG_OFFSET_CONTROL);
 	udelay(50);
@@ -302,7 +304,7 @@ static void snd_via686a_channel_reset(via686a_t *codec, viadev_t *viadev)
 static int snd_via686a_trigger(via686a_t *codec, viadev_t *viadev, int cmd)
 {
 	unsigned char val = 0;
-	unsigned int port = codec->port + viadev->reg_offset;
+	unsigned long port = codec->port + viadev->reg_offset;
 	
 	switch (cmd) {
 	case SND_PCM_TRIGGER_GO:
@@ -331,7 +333,7 @@ static void snd_via686a_setup_fragments(via686a_t *codec, viadev_t *viadev,
 {
 	int idx, frags;
 	unsigned int *table = viadev->table;
-	unsigned int port = codec->port + viadev->reg_offset;
+	unsigned long port = codec->port + viadev->reg_offset;
 
 	snd_via686a_channel_reset(codec, viadev);
 	outl(virt_to_bus(viadev->table), port + VIA_REG_OFFSET_TABLE_PTR);
@@ -484,6 +486,7 @@ static int snd_via686a_capture_prepare(void *private_data,
 	codec->capture.physbuf = virt_to_bus(runtime->dma_area->buf);
 	codec->capture.size = snd_pcm_lib_transfer_size(subchn);
 	codec->capture.fragsize = snd_pcm_lib_transfer_fragment(subchn);
+	codec->capture.position = 0;
 	/* disable ADC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_POWERDOWN, ~0x0100, 0x0100);
 	snd_ac97_write_lock(codec->ac97, AC97_PCM_LR_ADC_RATE, runtime->format.rate);
@@ -734,6 +737,7 @@ static int snd_via686a_playback_fm_prepare(void *private_data,
 	codec->playback_fm.physbuf = virt_to_bus(runtime->dma_area->buf);
 	codec->playback_fm.size = snd_pcm_lib_transfer_size(subchn);
 	codec->playback_fm.fragsize = snd_pcm_lib_transfer_fragment(subchn);
+	codec->playback_fm.position = 0;
 	/* disable DAC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_POWERDOWN, ~0x0200, 0x0200);
 	snd_ac97_write_lock(codec->ac97, AC97_PCM_FRONT_DAC_RATE, runtime->format.rate);
@@ -1172,6 +1176,10 @@ static int __init snd_via686a_probe(int dev, via686a_card_t *scard)
 	return -ENODEV;
 
       __found:
+	if (pci_enable_device(scard->pci)) {
+		snd_card_free(card);
+		return -ENODEV;
+	}
 	if (snd_via686a_resources(card, scard, dev) < 0) {
 		snd_card_free(card);
 		return -ENODEV;
@@ -1257,8 +1265,8 @@ static int __init snd_via686a_probe(int dev, via686a_card_t *scard)
 	strcpy(card->abbreviation, "VIA686A");
 	strcpy(card->shortname, "VIA 82C686A");
 	
-	sprintf(card->longname, "%s at 0x%lx, irq %i",
-		card->shortname, (long unsigned int)codec->port, scard->irqptr->irq);
+	sprintf(card->longname, "%s at 0x%lx, irq %li",
+		card->shortname, codec->port, scard->irqptr->irq);
 
 	if (!snd_card_register(card)) {
 		scard->card = card;
