@@ -59,7 +59,7 @@ MODULE_PARM_DESC(snd_index, "Index value for WaveFront soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
 MODULE_PARM_DESC(snd_id, "ID string for WaveFront soundcard.");
 MODULE_PARM(snd_cs4232_pcm_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_4232_port, "Port # for CS4232 PCM interface. [PORT12]");
+MODULE_PARM_DESC(snd_cs4232_pcm_port, "Port # for CS4232 PCM interface. [PORT12]");
 MODULE_PARM(snd_cs4232_pcm_irq, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_cs4232_pcm_irq, "IRQ # for CS4232 PCM interface. [list=5,7,9,11,12,15]");
 MODULE_PARM(snd_dma1, "1-" __MODULE_STRING(SND_CARDS) "i");
