@@ -26,6 +26,23 @@
 #include "../include/opl3.h"
 #include "../include/initval.h"
 
+#define CARD_NAME "Yamaha DS-XG PCI"
+#define DRIVER_NAME "YMFPCI"
+
+#define TEST_INTERRUPT 1
+/*
+   This flag enables the interrupt test.
+   For example, in the case of VAIO N-505, if you connect USB floppy
+   and disable PnP OS on BIOS, it sends bunch of interrupts on the same
+   IRQ (9) and results in a dead lock.  By enabling this option,
+   the driver checks such bogus interrupts, and aborts the installation.
+   If you should encounter this behavior,
+   1) don't connect USB device until the the kernel is booted, or
+   2) load usb-uhci module to initialize USB.
+
+   -- iwai
+*/
+
 MODULE_DESCRIPTION("\
 Driver: Yamaha DS-XG PCI\n\
 Card: YMF724\n\
@@ -52,23 +69,23 @@ int snd_fm_port[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = -1};
 int snd_mpu_port[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = -1};
 int snd_mpu_irq[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = -1 };
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_index, "Index value for the Yamaha DS-XG PCI soundcard.");
+MODULE_PARM_DESC(snd_index, "Index value for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
-MODULE_PARM_DESC(snd_id, "ID string for the Yamaha DS-XG PCI soundcard.");
+MODULE_PARM_DESC(snd_id, "ID string for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_enable, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_enable, "Enable Yamaha DS-XG soundcard. [BOOL]");
+MODULE_PARM_DESC(snd_enable, "Enable this soundcard. [BOOL]");
 MODULE_PARM(snd_dac_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_dac_frame_size, "DAC frame size in kB for the Yamaha DS-XG soundcard.");
+MODULE_PARM_DESC(snd_dac_frame_size, "DAC frame size in kB for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_adc_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_adc_frame_size, "ADC frame size in kB for the Yamaha DS-XG soundcard.");
+MODULE_PARM_DESC(snd_adc_frame_size, "ADC frame size in kB for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_ac97_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_ac97_frame_size, "Direct AC'97 frame size in kB for the Yamaha DS-XG soundcard.");
+MODULE_PARM_DESC(snd_ac97_frame_size, "Direct AC'97 frame size in kB for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_mpu_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_mpu_port, "MPU-401 port. [list=0x330,0x320,0x310,0x300]");
+MODULE_PARM_DESC(snd_mpu_port, "MPU-401 port # for " DRIVER_NAME " driver. [list=0x330,0x320,0x310,0x300]");
 MODULE_PARM(snd_mpu_irq, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_mpu_irq, "MPU-401 IRQ number [list=5,7,0,10,11].");
+MODULE_PARM_DESC(snd_mpu_irq, "MPU-401 IRQ # for " DRIVER_NAME " driver. [list=5,7,0,10,11]");
 MODULE_PARM(snd_fm_port, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_fm_port, "FM port. [list=0x388,0x3c8,0x3e0,0x3e8]");
+MODULE_PARM_DESC(snd_fm_port, "FM port # for " DRIVER_NAME " driver. [list=0x388,0x3c8,0x3e0,0x3e8]");
 
 struct snd_ymfpci {
 	struct pci_dev *pci;
@@ -108,6 +125,43 @@ static void snd_card_ymfpci_use_dec(snd_card_t * card)
 	MOD_DEC_USE_COUNT;
 }
 
+#ifdef TEST_INTERRUPT
+static int __initdata test_int_count = 0;
+static int __initdata test_irq_disabled = 0;
+static void __init
+test_bogus_interrupt(int irq, void *dev_id, struct pt_regs *regs)
+{
+	test_int_count++;
+	if (test_int_count > 20) {
+		disable_irq(irq);
+		snd_printk("YMF PCI: irq %d seems conflicted.. abort installation\n", irq);
+		test_irq_disabled = 1;
+	}
+}
+
+static int __init
+snd_card_ymfpci_test_interrupt(snd_card_t *card, int irq)
+{
+	test_int_count = 0;
+	test_irq_disabled = 0;
+	if (request_irq(irq, test_bogus_interrupt, 0, "ymfpci test", card)) {
+		if (request_irq(irq, test_bogus_interrupt, SA_SHIRQ, "ymfpci test", card))
+			return -EBUSY;
+		free_irq(irq, card);
+		return 0;  /* IRQ already shared.. */
+	}
+	set_current_state(TASK_UNINTERRUPTIBLE);
+	schedule_timeout(HZ/100);
+	if (test_irq_disabled)
+		enable_irq(irq);
+	free_irq(irq, card);
+	if (test_int_count)
+		return -EBUSY;
+	return 0;
+}
+
+#endif
+
 static void snd_card_ymfpci_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 {
 	struct snd_ymfpci *scard = (struct snd_ymfpci *) dev_id;
@@ -278,10 +332,10 @@ static int __init snd_card_ymfpci_probe(struct pci_dev *pci,
 	pci_read_config_word(pci, 0x40, &scard->old_legacy_ctrl);
 	switch (snd_mpu_irq[dev]) {
 	case 5:	break;
-	case 7:	legacy_ctrl |= 1 << 10; break;
-	case 9: legacy_ctrl |= 2 << 10; break;
-	case 10: legacy_ctrl |= 3 << 10; break;
-	case 11: legacy_ctrl |= 4 << 10; break;
+	case 7:	legacy_ctrl |= 1 << 11; break;
+	case 9: legacy_ctrl |= 2 << 11; break;
+	case 10: legacy_ctrl |= 3 << 11; break;
+	case 11: legacy_ctrl |= 4 << 11; break;
 	default: snd_mpu_irq[dev] = -1; break;
 	}
 	legacy_ctrl |= (snd_mpu_irq[dev] > 0 ? 0x10 : 0);	/* MPU401 IRQ enable */
@@ -289,6 +343,10 @@ static int __init snd_card_ymfpci_probe(struct pci_dev *pci,
 	pci_write_config_word(pci, 0x40, legacy_ctrl);
 	snd_printd("legacy_ctrl2 = 0x%x\n", legacy_ctrl2);
 	pci_write_config_word(pci, 0x42, legacy_ctrl2);
+#ifdef TEST_INTERRUPT
+	if ((err = snd_card_ymfpci_test_interrupt(card, scard->pci->irq)) < 0)
+		goto __nodev;
+#endif
 	if ((err = snd_register_interrupt(card,
 			str, scard->pci->irq,
 			SND_IRQ_TYPE_PCI, snd_card_ymfpci_interrupt,
@@ -296,7 +354,7 @@ static int __init snd_card_ymfpci_probe(struct pci_dev *pci,
 		goto __nodev;
 	if (snd_mpu_irq[dev] > 0) {
 		tmp = -1;
-		sprintf(str1, "%s - MPU401\n", str);
+		sprintf(str1, "%s - MPU401", str);
 		if ((err = snd_register_interrupt(card,
 				str1, snd_mpu_irq[dev],
 				SND_IRQ_TYPE_ISA, snd_card_ymfpci_mpu401_interrupt,
