@@ -90,8 +90,18 @@
 #define SND_CARD_TYPE_AZT2320		0x00000038	/* AZT2320 */
 #define SND_CARD_TYPE_PRODIF_PLUS	0x00000039	/* Marian/Sek'D Prodif Plus */
 #define SND_CARD_TYPE_YMFPCI		0x0000003a	/* YMF724/740/744/754 */
+#define SND_CARD_TYPE_ALS4000		0x0000003b	/* ALS4000 */
+#define SND_CARD_TYPE_AWACS		0x0000003c	/* PMac AWACS */
+#define SND_CARD_TYPE_ALI_5451		0x0000003d	/* ALi 5451 */
+#define SND_CARD_TYPE_CS4281		0x0000003e	/* CS4281 */
+#define SND_CARD_TYPE_ALLEGRO_1		0x0000003f	/* ESS Allegro-1 */
+#define SND_CARD_TYPE_ALLEGRO		0x00000040	/* ESS Allegro */
+#define SND_CARD_TYPE_MAESTRO3		0x00000041	/* ESS Maestro3 */
+#define SND_CARD_TYPE_NM256AV		0x00000042	/* NM256AV */
+#define SND_CARD_TYPE_NM256ZX		0x00000043	/* NM256ZX */
+#define SND_CARD_TYPE_VIA8233		0x00000044	/* VIA VT8233 */
 
 /* --- */
-#define SND_CARD_TYPE_LAST		0x0000003a
+#define SND_CARD_TYPE_LAST		0x00000044
 
 #endif				/* __ASOUNDID_H */
