@@ -3,6 +3,8 @@
  */
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0)
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,2,18)
+
 #define init_MUTEX(x) *(x) = MUTEX
 #define DECLARE_MUTEX(x) struct semaphore x = MUTEX
 typedef struct wait_queue wait_queue_t;
@@ -10,6 +12,17 @@ typedef struct wait_queue * wait_queue_head_t;
 #define init_waitqueue_head(x) *(x) = NULL
 #define init_waitqueue_entry(q,p) ((q)->task = (p))
 #define set_current_state(xstate) do { current->state = xstate; } while (0)
+
+/*
+ * Insert a new entry before the specified head..
+ */
+static __inline__ void list_add_tail(struct list_head *new, struct list_head *head)
+{
+	__list_add(new, head->prev, head);
+}
+
+#endif /* <2.2.18 */
+
 #define virt_to_page(x) (&mem_map[MAP_NR(x)])
 
 #define local_irq_save(flags) \
@@ -18,6 +31,7 @@ typedef struct wait_queue * wait_queue_head_t;
 	do { __restore_flags(flags); } while (0)
 
 #define __init
+#define __initdata
 #define __exit
 #define __exitdata
 #define __devinit
@@ -35,13 +49,14 @@ typedef struct wait_queue * wait_queue_head_t;
 
 #define MODULE_DEVICE_TABLE(foo,bar)
 
-/*
- * Insert a new entry before the specified head..
+
+/**
+ * list_for_each        -       iterate over a list
+ * @pos:        the &struct list_head to use as a loop counter.
+ * @head:       the head for your list.
  */
-static __inline__ void list_add_tail(struct list_head *new, struct list_head *head)
-{
-	__list_add(new, head->prev, head);
-}
+#define list_for_each(pos, head) \
+	for (pos = (head)->next; pos != (head); pos = pos->next)
 
 #define IORESOURCE_IO           0x00000100      /* Resource type */
 #define IORESOURCE_MEM          0x00000200
@@ -61,6 +76,7 @@ static __inline__ void list_add_tail(struct list_head *new, struct list_head *he
 #define pci_enable_device snd_pci_compat_enable_device
 #define pci_register_driver snd_pci_compat_register_driver
 #define pci_unregister_driver snd_pci_compat_unregister_driver
+#define pci_set_power_state snd_pci_compat_set_power_state
 
 #define pci_dev_g(n) list_entry(n, struct pci_dev, global_list)
 #define pci_dev_b(n) list_entry(n, struct pci_dev, bus_list)
