@@ -3,6 +3,7 @@
 
 /*
  *  Copyright (c) by Jaroslav Kysela <perex@suse.cz>
+ *                   Cirrus Logic, Inc.
  *  Definitions for Cirrus Logic CS461x chips
  *
  *
@@ -1619,6 +1620,13 @@
 #define CS461X_MODE_OUTPUT	(1<<0)	 /* MIDI UART - output */ 
 #define CS461X_MODE_INPUT	(1<<1)	 /* MIDI UART - input */
 
+/*
+ *
+ */
+
+#define SAVE_REG_MAX             0x10
+#define POWER_DOWN_ALL         0x7f0f
+
 /*
  *
  */
@@ -1681,6 +1689,9 @@ struct snd_stru_cs461x {
 	unsigned int midcr;
 	unsigned int uartm;
 	snd_info_entry_t *proc_entry;
+#ifdef CONFIG_APM
+	struct pm_dev *pm_dev;
+#endif
 };
 
 int snd_cs461x_create(snd_card_t * card,
