@@ -112,6 +112,9 @@
 #include <linux/pm.h>
 #define PCI_GET_DRIVER_DATA(pci) pci->driver_data
 #define PCI_SET_DRIVER_DATA(pci, data) pci->driver_data = data
+#ifndef virt_to_page
+#define virt_to_page(x) (&mem_map[MAP_NR(x)])
+#endif
 #endif
 
 #if defined(CONFIG_ISAPNP) || (defined(CONFIG_ISAPNP_MODULE) && defined(MODULE))
@@ -147,6 +150,17 @@ static inline void snd_leave_user(mm_segment_t fs)
 	set_fs(fs);
 }
 
+#if defined(__alpha__) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 3, 14)
+#undef writeb
+#define writeb(v, a) ({__writeb((v),(a)); mb(); })
+#undef writew
+#define writew(v, a) ({__writew((v),(a)); mb(); })
+#undef writel
+#define writel(v, a) ({__writel((v),(a)); mb(); })
+#undef writeq
+#define writeq(v, a) ({__writeq((v),(a)); mb(); })
+#endif
+
 /*
  *  ==========================================================================
  */
