@@ -30,6 +30,9 @@
 #ifndef PCI_DEVICE_ID_INTEL_82801
 #define PCI_DEVICE_ID_INTEL_82801	0x2415
 #endif
+#ifndef PCI_DEVICE_ID_INTEL_82801BA
+#define PCI_DEVICE_ID_INTEL_82801BA	0x2445
+#endif
 #ifndef PCI_DEVICE_ID_INTEL_82901
 #define PCI_DEVICE_ID_INTEL_82901	0x2425
 #endif
@@ -81,6 +84,10 @@
 #define ICH_REG_MC_CR			0x2b	/* byte - control register */
 /* global block */
 #define ICH_REG_GLOB_CNT		0x2c	/* dword - global control */
+#define   ICH_PCM_246_MASK	0x00300000	/* 6 channels (not all chips) */
+#define   ICH_PCM_6		0x00200000	/* 6 channels (not all chips) */
+#define   ICH_PCM_4		0x00100000	/* 4 channels (not all chips) */
+#define   ICH_PCM_2		0x00000000	/* 2 channels (stereo) */
 #define   ICH_SRIE		0x00000020	/* secondary resume interrupt enable */
 #define   ICH_PRIE		0x00000010	/* primary resume interrupt enable */
 #define   ICH_ACLINK		0x00000008	/* AClink shut off */
@@ -149,6 +156,7 @@ struct snd_stru_intel8x0 {
 	ichdev_t capture_mic;
 
 	ac97_t *ac97;
+	unsigned int ac97_clock;
 	unsigned short ac97_ext_id;
 	snd_kmixer_t *mixer;
 
@@ -164,6 +172,7 @@ int snd_intel8x0_create(snd_card_t * card,
 		       snd_dma_t * dma_cap,
 		       snd_dma_t * dma_mic,
 		       snd_irq_t * irqptr,
+		       unsigned int ac97_clock,
 		       intel8x0_t ** codec);
 int snd_intel8x0_free(intel8x0_t * codec);
 void snd_intel8x0_interrupt(intel8x0_t * codec);
