@@ -119,6 +119,15 @@ static inline int _snd_magic_bad(void *obj, unsigned int magic)
 #define cmipci_t_magic				0xa15a2e01
 #define ymfpci_t_magic				0xa15a2f01
 #define ymfpci_pcm_t_magic			0xa15a2f02
+#define als4000dsp_t_magic			0xa15a3001
+#define pmac_t_magic				0xa15a3101
+#define pmac_mixer_group_t_magic		0xa15a3202
+#define cs4281_t_magic				0xa15a3301
+#define m3_t_magic				0xa15a3401
+#define m3_dma_t_magic				0xa15a3402
+#define nm256_t_magic				0xa15a3501
+#define nm256_dma_t_magic			0xa15a2502
+#define via8233_t_magic				0xa15a2601
 
 #else
 #define snd_magic_kcalloc(type, extra, flags) (type *) snd_kcalloc(sizeof(type) + extra, flags)
