@@ -906,7 +906,7 @@ static int snd_pcm_mmap(struct inode *inode, struct file *file,
 		vma->notify_data = runtime->mmap_control;
 		vma->notify_size = sizeof(snd_pcm_mmap_control_t);
 		if (remap_page_range(area->vm_start,
-				     virt_to_bus(runtime->mmap_control),
+				     virt_to_phys(runtime->mmap_control),
 				     PAGE_ALIGN(sizeof(snd_pcm_mmap_control_t)),
 				     area->vm_page_prot)) {
 			snd_free_pages(runtime->mmap_control, sizeof(snd_pcm_mmap_control_t));
@@ -957,7 +957,7 @@ static int snd_pcm_mmap(struct inode *inode, struct file *file,
 		vma->notify_data = ptr;
 		vma->notify_size = size1;
 		if (remap_page_range(area->vm_start,
-				     virt_to_bus(ptr),
+				     virt_to_phys(ptr),
 				     size1,
 				     area->vm_page_prot)) {
 			snd_kfree(vma);
