@@ -662,9 +662,9 @@ static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, unsigned char *buf, l
 		if (count1 > pchn->used)
 			count1 = pchn->used;
 		if (kernel) {
-			memcpy(buf, pchn->buffer + pchn->tail, count1);
+			memcpy(buf + result, pchn->buffer + pchn->tail, count1);
 		} else {
-			if (copy_to_user(buf, pchn->buffer + pchn->tail, count1)) {
+			if (copy_to_user(buf + result, pchn->buffer + pchn->tail, count1)) {
 				spin_unlock_irqrestore(&pchn->lock, flags);
 				return result > 0 ? result : -EFAULT;
 			}
