@@ -136,6 +136,8 @@ receive_announce(snd_seq_event_t *ev, int direct, void *private, int atomic, int
 	switch (ev->type) {
 	case SND_SEQ_EVENT_PORT_START:
 	case SND_SEQ_EVENT_PORT_CHANGE:
+		if (ev->data.addr.client == system_client)
+			break; /* ignore myself */
 		memset(&pinfo, 0, sizeof(pinfo));
 		pinfo.client = ev->data.addr.client;
 		pinfo.port = ev->data.addr.port;
@@ -144,6 +146,8 @@ receive_announce(snd_seq_event_t *ev, int direct, void *private, int atomic, int
 		break;
 
 	case SND_SEQ_EVENT_PORT_EXIT:
+		if (ev->data.addr.client == system_client)
+			break; /* ignore myself */
 		snd_seq_oss_midi_check_exit_port(ev->data.addr.client,
 						ev->data.addr.port);
 		break;
@@ -463,8 +467,10 @@ snd_seq_oss_reset(seq_oss_devinfo_t *dp)
 		snd_seq_oss_synth_reset(dp, i);
 
 	/* reset all midi devices */
-	for (i = 0; i < dp->max_mididev; i++)
-		snd_seq_oss_midi_reset(dp, i);
+	if (dp->seq_mode != SND_SEQ_OSS_MODE_MUSIC) {
+		for (i = 0; i < dp->max_mididev; i++)
+			snd_seq_oss_midi_reset(dp, i);
+	}
 
 	/* remove queues */
 	if (dp->readq)
