@@ -84,6 +84,8 @@ snd_seq_oss_midi_lookup_ports(int client)
 	memset(&clinfo, 0, sizeof(clinfo));
 	memset(&pinfo, 0, sizeof(pinfo));
 	for (i = 0; i < sysinfo.clients; i++) {
+		if (i == client)
+			continue;
 		clinfo.client = i;
 		if (snd_seq_kernel_client_ctl(client, SND_SEQ_IOCTL_GET_CLIENT_INFO, &clinfo) < 0)
 			continue;
@@ -440,13 +442,20 @@ snd_seq_oss_midi_filemode(seq_oss_devinfo_t *dp, int dev)
 void
 snd_seq_oss_midi_reset(seq_oss_devinfo_t *dp, int dev)
 {
-	if (dp->seq_mode == SND_SEQ_OSS_MODE_MUSIC) {
-		seq_oss_midi_t *mdev;
+	seq_oss_midi_t *mdev;
+
+	if ((mdev = get_mididev(dp, dev)) == NULL)
+		return;
+	if (! mdev->opened) {
+		snd_use_lock_free(&mdev->use_lock);
+		return;
+	}
+
+	if (dp->seq_mode == SND_SEQ_OSS_MODE_MUSIC &&
+	    (mdev->opened & PERM_WRITE)) {
 		snd_seq_event_t ev;
 		int c;
 
-		if ((mdev = get_mididev(dp, dev)) == NULL)
-			return;
 		memset(&ev, 0, sizeof(ev));
 		ev.dest.client = mdev->client;
 		ev.dest.port = mdev->port;
@@ -463,11 +472,9 @@ snd_seq_oss_midi_reset(seq_oss_devinfo_t *dp, int dev)
 			ev.data.control.value = 0;
 			snd_seq_oss_dispatch(dp, &ev, 0, 0); /* bender off */
 		}
-		snd_use_lock_free(&mdev->use_lock);
-		
-	} else {
-		snd_seq_oss_midi_close(dp, dev);
 	}
+	snd_seq_oss_midi_close(dp, dev);
+	snd_use_lock_free(&mdev->use_lock);
 }
 
 
