@@ -81,7 +81,7 @@ static inline unsigned short snd_seq_file_flags(struct file *file)
 
 static inline int snd_seq_write_pool_allocated(client_t *client)
 {
-	return snd_seq_total_cells(client->pool) > 0;
+	return /*client->pool &&*/ snd_seq_total_cells(client->pool) > 0;
 }
 
 /* return pointer to client structure for specified id */
@@ -1140,8 +1140,8 @@ static void get_client_info(client_t *cptr, snd_seq_client_info_t *info)
 
 	/* fill the info fields */
 	info->type = cptr->type;
-	strcpy(info->name, cptr->name);
-	strcpy(info->group, cptr->group);
+	strncpy(info->name, cptr->name, sizeof(cptr->name));
+	strncpy(info->group, cptr->group, sizeof(cptr->group));
 	info->filter = cptr->filter;
 	info->event_lost = cptr->event_lost;
 	memcpy(info->multicast_filter, cptr->multicast_filter, sizeof(info->multicast_filter));
@@ -2038,6 +2038,7 @@ static int snd_seq_ioctl_set_client_pool(client_t * client, snd_seq_client_pool_
 		return -EINVAL; /* can't change other clients */
 
 	if (info.output_pool >= 1 && info.output_pool <= SND_SEQ_MAX_EVENTS &&
+	    /*client->pool &&*/
 	    (! snd_seq_write_pool_allocated(client) ||
 	     info.output_pool != client->pool->size)) {
 		if (snd_seq_write_pool_allocated(client)) {
@@ -2736,7 +2737,7 @@ void snd_seq_info_clients_read(snd_info_buffer_t * buffer, void *private_data)
 					snd_iprintf(buffer, "  Output pool :\n");
 					snd_seq_info_pool(buffer, client->pool, "    ");
 				}
-				if (client->data.user.fifo->pool) {
+				if (client->data.user.fifo && client->data.user.fifo->pool) {
 					snd_iprintf(buffer, "  Input pool :\n");
 					snd_seq_info_pool(buffer, client->data.user.fifo->pool, "    ");
 				}
