@@ -252,7 +252,7 @@ static int compare_instr(snd_seq_instr_t *i1, snd_seq_instr_t *i2, int exact)
 			return 1;
 		if ((i1->std & 0xff000000) != (i2->std & 0xff000000))
 			return 1;
-		if ((i1->std & i2->std) != 0)
+		if (! (i1->std & i2->std))
 			return 1;
 		return 0;
 	} else {
@@ -268,7 +268,7 @@ static int compare_instr(snd_seq_instr_t *i1, snd_seq_instr_t *i2, int exact)
 			if ((i1->std & i2->std) != i2->std)
 				return 1;
 		}
-		return i1->bank != i2->bank && i1->prg != i2->prg;
+		return i1->bank != i2->bank || i1->prg != i2->prg;
 	}
 }
 
