@@ -111,11 +111,17 @@ snd_midi_process_event(snd_midi_op_t *ops,
 
 	switch (ev->type) {
 	case SND_SEQ_EVENT_NOTEON:
+		if (chan->note[ev->data.note.note] & SND_MIDI_NOTE_ON) {
+			if (ops->note_off)
+				ops->note_off(drv, ev->data.note.note, 0, chan);
+		}
 		chan->note[ev->data.note.note] = SND_MIDI_NOTE_ON;
 		if (ops->note_on)
 			ops->note_on(drv, ev->data.note.note, ev->data.note.velocity, chan);
 		break;
 	case SND_SEQ_EVENT_NOTEOFF:
+		if (! (chan->note[ev->data.note.note] & SND_MIDI_NOTE_ON))
+			break;
 		if (ops->note_off)
 			note_off(ops, drv, chan, ev->data.note.note, ev->data.note.velocity);
 		break;
