@@ -372,16 +372,14 @@ int snd_seq_enqueue_event(snd_seq_event_cell_t *cell, int atomic, int hop)
 		switch (cell->event.flags & SND_SEQ_TIME_STAMP_MASK) {
 			case SND_SEQ_TIME_STAMP_TICK:
 				cell->event.time.tick += q->timer->cur_tick;
-				cell->event.flags &= ~SND_SEQ_TIME_STAMP_MASK;
-				cell->event.flags |= SND_SEQ_TIME_STAMP_TICK;
 				break;
 
 			case SND_SEQ_TIME_STAMP_REAL:
 				snd_seq_inc_real_time(&cell->event.time.time, &q->timer->cur_time);
-				cell->event.flags &= ~SND_SEQ_TIME_STAMP_MASK;
-				cell->event.flags |= SND_SEQ_TIME_STAMP_REAL;
 				break;
 		}
+		cell->event.flags &= ~SND_SEQ_TIME_MODE_MASK;
+		cell->event.flags |= SND_SEQ_TIME_MODE_ABS;
 	}
 	/* enqueue event in the real-time or midi queue */
 	switch (cell->event.flags & SND_SEQ_TIME_STAMP_MASK) {
