@@ -624,7 +624,7 @@ int snd_timer_register(snd_timer_t * timer, snd_device_t *devptr)
 	snd_debug_check(devptr == NULL, -ENXIO);
 	device = devptr->number;
 	if (!(timer->hw.flags & SND_TIMER_HW_SLAVE) &&
-	    !timer->hw.resolution)
+	    !timer->hw.resolution && timer->hw.c_resolution == NULL)
 	    	return -EINVAL;
 	if (device & SND_TIMER_DEV_FLG_PCM) {
 		snd_debug_check(timer->card == NULL, -ENXIO);
