@@ -302,7 +302,7 @@ static void snd_emu10k1_pcm_init_voice(emu10k1_t *emu, int master,
 	snd_emu10k1_ptr_write(emu, Z1, voice, 0);
 	snd_emu10k1_ptr_write(emu, Z2, voice, 0);
 	// invalidate maps
-	silent_page = ((unsigned int)virt_to_phys(emu->silent_page) << 1) | MAP_PTI_MASK;
+	silent_page = ((unsigned int)virt_to_bus(emu->silent_page) << 1) | MAP_PTI_MASK;
 	snd_emu10k1_ptr_write(emu, MAPA, voice, silent_page);
 	snd_emu10k1_ptr_write(emu, MAPB, voice, silent_page);
 	// fill cache
@@ -381,7 +381,7 @@ static int snd_emu10k1_capture_prepare(void *private_data,
 	default:
 		break;
 	}	
-	snd_emu10k1_ptr_write(emu, epcm->capture_ba_reg, 0, (unsigned int)virt_to_phys(runtime->dma_area->buf));
+	snd_emu10k1_ptr_write(emu, epcm->capture_ba_reg, 0, (unsigned int)virt_to_bus(runtime->dma_area->buf));
 	epcm->capture_bs_val = snd_emu10k1_capture_transfer_reg(epcm->capture_bufsize = snd_pcm_lib_transfer_size(subchn));
 	if (epcm->type == CAPTURE_AC97ADC) {
 		epcm->capture_cr_val = ADCCR_LCHANENABLE;
