@@ -29,7 +29,7 @@
  * aligned pages in others
  */
 #define __set_ptb_phys(emu,page,ptr)	((emu)->ptb_pages[page] = (ptr << 1) | (page))
-#define __ptb_to_ptr(emu,pg)	(void*)phys_to_virt(((emu)->ptb_pages[pg] >> 1) & ~(EMUPAGESIZE - 1))
+#define __ptb_to_ptr(emu,pg)	(void*)bus_to_virt(((emu)->ptb_pages[pg] >> 1) & ~(EMUPAGESIZE - 1))
 
 #if PAGE_SIZE == 4096
 /* page size == EMUPAGESIZE */
@@ -65,7 +65,7 @@ static inline void set_ptb_phys(emu10k1_t *emu, int page, unsigned long ptr)
 }
 static inline void set_silent_ptb(emu10k1_t *emu, int page)
 {
-	unsigned long ptr = (unsigned long)virt_to_phys(emu->silent_page);
+	unsigned long ptr = (unsigned long)virt_to_bus(emu->silent_page);
 	page <<= 1;
 	__set_ptb_phys(emu, page, ptr);
 	page++;
@@ -99,7 +99,7 @@ static inline void set_ptb_phys(emu10k1_t *emu, int page, unsigned long ptr)
 }
 static inline void set_silent_ptb(emu10k1_t *emu, int page)
 {
-	unsigned long ptr = (unsigned long)virt_to_phys(emu->silent_page);
+	unsigned long ptr = (unsigned long)virt_to_bus(emu->silent_page);
 	int i;
 	page *= UNIT_PAGES;
 	for (i = 0; i < UNIT_PAGES; i++, page++)
@@ -118,7 +118,7 @@ inline static void *offset_ptr(emu10k1_t *emu, int offset)
 }
 
 /* fill PTB entries with virtual address ptr */
-#define set_ptb_virt(emu,page,ptr)	set_ptb_phys(emu, page, (unsigned int)virt_to_phys(ptr))
+#define set_ptb_virt(emu,page,ptr)	set_ptb_phys(emu, page, (unsigned int)virt_to_bus(ptr))
 
 /* first and last (aligned) pages of memory block */
 #define firstpg(blk)	(((snd_emu10k1_memblk_arg_t*)snd_emux_memblk_argptr(blk))->first_page)
@@ -161,7 +161,7 @@ __found_pages:
  */
 static int is_valid_page(void *pages)
 {
-	unsigned long ptr = (unsigned long)virt_to_phys(pages);
+	unsigned long ptr = (unsigned long)virt_to_bus(pages);
 	if (ptr & ~0x7fffffffUL) {
 		snd_printk("emu10k1: max memory size is 2GB!!\n");
 		return 0;
@@ -199,7 +199,7 @@ snd_emu10k1_alloc_pages(emu10k1_t *emu, void *pages, unsigned long size)
 		return NULL;
 	}
 	/* set PTB entries */
-	ptr = (unsigned long)virt_to_phys(pages);
+	ptr = (unsigned long)virt_to_bus(pages);
 	for (page = firstpg(blk); page <= lastpg(blk); page++) {
 		set_ptb_phys(emu, page, ptr);
 		ptr += ALIGN_PAGE_SIZE;
