@@ -60,9 +60,12 @@ static struct {
 	{	0x414b4d02,	"AK4543",			},
 	{	0x41445303,	"AD1819"			},
 	{	0x41445340,	"AD1881"			},
+	{	0x41445348,	"AD1881A"			},
+	{	0x41445360,	"AD1885"			},
 	{	0x414c4710,	"ALC200/200P"			},
 	{	0x43525903,	"CS4297"			},
-	{	0x43525913,	"CS4297A"			},
+	{	0x43525913,	"CS4297A rev A"			},
+	{	0x43525914,	"CS4297A rev B"			},
 	{	0x42525923,	"CS4294"			},
 	{	0x43525931,	"CS4299 rev A"			},
 	{	0x43525933,	"CS4299 rev C"			},
@@ -131,6 +134,8 @@ static int snd_ac97_valid_reg(ac97_t *ac97, unsigned short reg)
 		return 0;
 	case 0x41445303:	/* AD1819 */
 	case 0x41445340:	/* AD1881 */
+	case 0x41445348:	/* AD1881A */
+	case 0x41445360:	/* AD1885 */
 		if (reg >= 0x3a && reg <= 0x59)
 			return 0;
 		return 1;
@@ -1544,8 +1549,9 @@ static int snd_ac97_mixer_build(snd_kmixer_t * mixer, ac97_t * ac97, int pcm_cou
 					      SND_MIXER_OSS_MIC,
 					      snd_ac97_mixer_group_mic))
 			goto __error;
-		if (snd_mixer_element_route_add(mixer, ac97->me_sw_mic, ac97->me_bypass_accu) < 0)
-			goto __error;
+		if (ac97->me_bypass_accu != NULL)
+			if (snd_mixer_element_route_add(mixer, ac97->me_sw_mic, ac97->me_bypass_accu) < 0)
+				goto __error;
 		ac97->me_mux2_mic = ac97->me_mux_mic;
 		if (snd_mixer_element_route_add(mixer, ac97->me_mux_mic, ac97->me_mono_mux) < 0)
 			goto __error;
@@ -2219,6 +2225,18 @@ static int snd_ac97_TriTech5452_4108(ac97_t * ac97)
 	return 0;
 }
 
+//---------------------------------------------------------------------------
+static int snd_ac97_AD1885(ac97_t * ac97)
+{
+	// detect the Analog Devices AD1885
+	if (ac97->id == 0x41445460) {
+		// enable EAPD
+		snd_ac97_write(ac97, AC97_POWERDOWN, snd_ac97_read(ac97, AC97_POWERDOWN) | 0x8000);
+		return 1;
+	}
+	return 0;
+}
+
 static void snd_ac97_chip_init(ac97_t * ac97)
 {
 	if (snd_ac97_TriTech5452_4108(ac97))	// patch for TriTech 5452 and 4108
@@ -2229,6 +2247,8 @@ static void snd_ac97_chip_init(ac97_t * ac97)
 		return;
 	if (snd_ac97_Wolfson574D_4C0X(ac97))	// patch for Wolfson
 		return;
+	if (snd_ac97_AD1885(ac97))		// patch for AD1885
+		return;
 }
 
 /*
