@@ -2,7 +2,7 @@
  *  Midi synth routines for the Emu8k/Emu10k1
  *
  *  Copyright (C) 1999 Steve Ratcliffe
- *  Copyright (c) 1999-2000 Takashi Iwai <iwai@ww.uni-erlangen.de>
+ *  Copyright (c) 1999-2000 Takashi Iwai <tiwai@suse.de>
  *
  *  Contains code based on awe_wave.c by Takashi Iwai
  *
@@ -80,8 +80,10 @@ snd_emux_note_on(void *p, int note, int vel, snd_midi_channel_t *chan)
 			exclusive_note_off(emu, port, zp->v.exclusiveClass);
 	}
 
+#if 0
 	/* Turn off the same note on the same channel. */
 	terminate_note1(emu, key, chan, 0);
+#endif
 
 	spin_lock_irqsave(&emu->voice_lock, flags);
 	for (i = 0; i < nvoices; i++) {
@@ -482,6 +484,9 @@ static unsigned short voltarget[16] = {
 	0xA5F8, 0x9EF0, 0x9830, 0x91C0, 0x8B90, 0x85A8, 0x8000, 0x7A90
 };
 
+#define LO_BYTE(v)	((v) & 0xff)
+#define HI_BYTE(v)	(((v) >> 8) & 0xff)
+
 /*
  * Sets up the voice structure by calculating some values that
  * will be needed later.
@@ -489,7 +494,7 @@ static unsigned short voltarget[16] = {
 static void
 setup_voice(snd_emux_voice_t *vp)
 {
-	soundfont_voice_parm_block_t *parm;
+	soundfont_voice_parm_t *parm;
 	int pitch;
 
 	/* copy the original register values */
@@ -508,16 +513,16 @@ setup_voice(snd_emux_voice_t *vp)
 	calc_pitch(vp);
 	calc_pan(vp);
 
-	parm = (soundfont_voice_parm_block_t*)&vp->reg.parm;
+	parm = &vp->reg.parm;
 
 	/* compute filter target and correct modulation parameters */
-	if (parm->modatk >= 0x80 && parm->moddelay >= 0x8000) {
+	if (LO_BYTE(parm->modatkhld) >= 0x80 && parm->moddelay >= 0x8000) {
 		parm->moddelay = 0xbfff;
-		pitch = (parm->env1pit << 4) + vp->apitch;
+		pitch = (HI_BYTE(parm->pefe) << 4) + vp->apitch;
 		if (pitch > 0xffff)
 			pitch = 0xffff;
 		/* calculate filter target */
-		vp->ftarget = parm->cutoff + parm->env1fc;
+		vp->ftarget = parm->cutoff + LO_BYTE(parm->pefe);
 		LIMITVALUE(vp->ftarget, 0, 255);
 		vp->ftarget <<= 8;
 	} else {
@@ -537,19 +542,23 @@ setup_voice(snd_emux_voice_t *vp)
 	} else
 		vp->ptarget = 0xffff;
 
-	if (parm->modatk >= 0x80)
-		parm->modatk = 0x7f;
+	if (LO_BYTE(parm->modatkhld) >= 0x80) {
+		parm->modatkhld &= ~0xff;
+		parm->modatkhld |= 0x7f;
+	}
 
 	/* compute volume target and correct volume parameters */
-	if (parm->volatk >= 0x80 && parm->voldelay >= 0x8000) {
+	if (LO_BYTE(parm->volatkhld) >= 0x80 && parm->voldelay >= 0x8000) {
 		parm->voldelay = 0xbfff;
 		vp->vtarget = voltarget[vp->avol % 0x10] >> (vp->avol >> 4);
 	} else {
 		vp->vtarget = 0;
 	}
 
-	if (parm->volatk >= 0x80)
-		parm->volatk = 0x7f;
+	if (LO_BYTE(parm->volatkhld) >= 0x80) {
+		parm->volatkhld &= ~0xff;
+		parm->volatkhld |= 0x7f;
+	}
 }
 
 /*
@@ -695,7 +704,7 @@ calc_volume(snd_emux_voice_t *vp)
 
 	vp->avol = vol;
 	if (!SF_IS_DRUM_BANK(get_bank(port, chan))
-	    && ((soundfont_voice_parm_block_t*)&vp->reg.parm)->volatk < 0x7d) {
+	    && LO_BYTE(vp->reg.parm.volatkhld) < 0x7d) {
 		int atten;
 		if (vp->velocity < 70)
 			atten = 70;
