@@ -193,7 +193,7 @@ static void snd_ad1848_mce_up(ad1848_t * codec)
 	codec->mce_bit |= AD1848_MCE;
 	timeout = inb(AD1848P(codec, REGSEL));
 	if (timeout == 0x80)
-		snd_printk("snd_ad1848_up [0x%x]: serious init problem - codec still busy\n", codec->port);
+		snd_printk("snd_ad1848_up [0x%lx]: serious init problem - codec still busy\n", codec->port);
 	if (!(timeout & AD1848_MCE))
 		outb(codec->mce_bit | (timeout & 0x1f), AD1848P(codec, REGSEL));
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
@@ -216,13 +216,13 @@ static void snd_ad1848_mce_down(ad1848_t * codec)
 #endif
 #ifdef CONFIG_SND_DEBUG
 	if (inb(AD1848P(codec, REGSEL)) & AD1848_INIT)
-		snd_printk("ad1848_mce_down [0x%x] - auto calibration time out (0)\n", AD1848P(codec, REGSEL));
+		snd_printk("ad1848_mce_down [0x%lx] - auto calibration time out (0)\n", AD1848P(codec, REGSEL));
 #endif
 	codec->mce_bit &= ~AD1848_MCE;
 	timeout = inb(AD1848P(codec, REGSEL));
 	outb(codec->mce_bit | (timeout & 0x1f), AD1848P(codec, REGSEL));
 	if (timeout == 0x80)
-		snd_printk("snd_ad1848_down [0x%x]: serious init problem - codec still busy\n", codec->port);
+		snd_printk("snd_ad1848_down [0x%lx]: serious init problem - codec still busy\n", codec->port);
 	if ((timeout & AD1848_MCE) == 0) {
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		return;
@@ -834,7 +834,7 @@ static int snd_ad1848_capture_close(void *private_data,
 }
 
 int snd_ad1848_new_pcm(snd_card_t * card, int device,
-		       unsigned short port,
+		       unsigned long port,
 		       snd_irq_t * irqptr,
 		       snd_dma_t * dmaptr,
 		       unsigned short hardware,
