@@ -1289,6 +1289,8 @@ static int snd_cs4231_capture_close(void *private_data,
 	return 0;
 }
 
+#ifdef CONFIG_APM
+
 static void snd_cs4231_suspend(cs4231_t * codec)
 {
 	int reg;
@@ -1348,20 +1350,26 @@ static int snd_cs4231_pm_callback(struct pm_dev *dev, pm_request_t rqst, void *d
 
 	switch (rqst) {
 	case PM_SUSPEND:
-		(*codec->suspend)(codec);
+		if (codec->suspend)
+			codec->suspend(codec);
 		break;
 	case PM_RESUME:
-		(*codec->resume)(codec);
+		if (codec->resume)
+			codec->resume(codec);
 		break;
 	}
 	return 0;
 }
 
+#endif /* CONFIG_APM */
+
 static void snd_cs4231_free(void *private_data)
 {
 	cs4231_t *codec = snd_magic_cast(cs4231_t, private_data, );
+#ifdef CONFIG_APM
 	if (codec->pm_dev)
 		pm_unregister(codec->pm_dev);
+#endif
 	if (codec->timer)
 		snd_device_free(codec->card, codec->timer);
 	snd_magic_kfree(codec);
@@ -1478,11 +1486,13 @@ int snd_cs4231_new_pcm(snd_card_t * card, int device,
 	memcpy(&timer->hw, &snd_cs4231_timer, sizeof(snd_cs4231_timer));
 	codec->timer = timer;
 
+#ifdef CONFIG_APM
 	codec->suspend = snd_cs4231_suspend;
 	codec->resume = snd_cs4231_resume;
 	codec->pm_dev = pm_register(PM_ISA_DEV, 0, snd_cs4231_pm_callback);
 	if (codec->pm_dev)
 		codec->pm_dev->data = codec;
+#endif
 
 	*rpcm = pcm;
 	return 0;
