@@ -214,6 +214,8 @@ static void snd_cs4236_capture_format(cs4231_t * codec, unsigned char cdfr)
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
 }
 
+#ifdef CONFIG_APM
+
 static void snd_cs4236_suspend(cs4231_t * codec)
 {
 	int reg;
@@ -262,6 +264,8 @@ static void snd_cs4236_resume(cs4231_t * codec)
 	snd_cs4231_mce_down(codec);
 }
 
+#endif /* CONFIG_APM */
+
 int snd_cs4236_new_pcm(snd_card_t * card, int device,
 		       unsigned long port,
 		       unsigned long cport,	/* control port */
@@ -321,8 +325,10 @@ int snd_cs4236_new_pcm(snd_card_t * card, int device,
 	  codec->set_capture_rate = snd_cs4236_xrate;
 	codec->set_playback_format = snd_cs4236_playback_format;
 	codec->set_capture_format = snd_cs4236_capture_format;
+#ifdef CONFIG_APM
 	codec->suspend = snd_cs4236_suspend;
 	codec->resume = snd_cs4236_resume;
+#endif
 	snd_cs4236_ext_out(codec, CS4236_DAC_MUTE, 0xe0);	/* IFSE enable, digital master mute */
 	*rpcm = pcm;
 	return 0;
