@@ -46,7 +46,7 @@ static int snd_es1688_dsp_get_byte(es1688_t * codec)
 	for (i = 1000; i; i--)
 		if (inb(ES1688P(codec, DATA_AVAIL)) & 0x80)
 			return inb(ES1688P(codec, READ));
-	snd_printd("es1688 get byte failed: 0x%x = 0x%x!!!\n", ES1688P(codec, DATA_AVAIL), inb(ES1688P(codec, DATA_AVAIL)));
+	snd_printd("es1688 get byte failed: 0x%lx = 0x%x!!!\n", ES1688P(codec, DATA_AVAIL), inb(ES1688P(codec, DATA_AVAIL)));
 	return -ENODEV;
 }
 
@@ -98,7 +98,7 @@ static int snd_es1688_reset(es1688_t * codec)
 	udelay(30);
 	for (i = 0; i < 1000 && !(inb(ES1688P(codec, DATA_AVAIL)) & 0x80); i++);
 	if (inb(ES1688P(codec, READ)) != 0xaa) {
-		snd_printd("ess_reset at 0x%x: failed!!!\n", codec->port);
+		snd_printd("ess_reset at 0x%lx: failed!!!\n", codec->port);
 		return -ENODEV;
 	}
 	snd_es1688_dsp_command(codec, 0xc6);	/* enable extended mode */
@@ -132,7 +132,7 @@ static int snd_es1688_probe(snd_pcm_t * pcm)
 	inb(ES1688P(codec, ENABLE0));	/* ENABLE0 */
 
 	if (snd_es1688_reset(codec) < 0) {
-		snd_printdd("ESS: [0x%x] reset failed... 0x%x\n", codec->port, inb(ES1688P(codec, READ)));
+		snd_printdd("ESS: [0x%lx] reset failed... 0x%x\n", codec->port, inb(ES1688P(codec, READ)));
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		return -ENODEV;
 	}
@@ -150,7 +150,7 @@ static int snd_es1688_probe(snd_pcm_t * pcm)
 
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
 
-	snd_printdd("ESS: [0x%x] found.. major = 0x%x, minor = 0x%x\n", codec->port, major, minor);
+	snd_printdd("ESS: [0x%lx] found.. major = 0x%x, minor = 0x%x\n", codec->port, major, minor);
 
 	codec->version = (major << 8) | minor;
 	if (!codec->version)
@@ -159,13 +159,13 @@ static int snd_es1688_probe(snd_pcm_t * pcm)
 	hw = ES1688_HW_AUTO;
 	switch (codec->version & 0xfff0) {
 	case 0x4880:
-		snd_printk("[0x%x] ESS: AudioDrive ES488 detected, but driver is in another place\n", codec->port);
+		snd_printk("[0x%lx] ESS: AudioDrive ES488 detected, but driver is in another place\n", codec->port);
 		return -ENODEV;
 	case 0x6880:
 		hw = (codec->version & 0x0f) >= 8 ? ES1688_HW_1688 : ES1688_HW_688;
 		break;
 	default:
-		snd_printk("[0x%x] ESS: unknown AudioDrive chip with version 0x%x (Jazz16 soundcard?)\n", codec->port, codec->version);
+		snd_printk("[0x%lx] ESS: unknown AudioDrive chip with version 0x%x (Jazz16 soundcard?)\n", codec->port, codec->version);
 		return -ENODEV;
 	}
 	switch (codec->hardware = hw) {
@@ -243,7 +243,7 @@ int snd_es1688_init(snd_pcm_t * pcm, int enable)
 		cfg = 0xf0;	/* enable only DMA counter interrupt */
 		irq_bits = irqs[codec->irq & 0x0f];
 		if (irq_bits < 0) {
-			snd_printk("[0x%x] ESS: bad IRQ %d for ES1688 chip!!\n", codec->port, codec->irq);
+			snd_printk("[0x%lx] ESS: bad IRQ %ld for ES1688 chip!!\n", codec->port, codec->irq);
 #if 0
 			irq_bits = 0;
 			cfg = 0x10;
@@ -256,7 +256,7 @@ int snd_es1688_init(snd_pcm_t * pcm, int enable)
 		cfg = 0xf0;	/* extended mode DMA enable */
 		dma = codec->dma8;
 		if (dma > 3 || dma == 2) {
-			snd_printk("[0x%x] ESS: bad DMA channel %d for ES1688 chip!!\n", codec->port, dma);
+			snd_printk("[0x%lx] ESS: bad DMA channel %d for ES1688 chip!!\n", codec->port, dma);
 #if 0
 			dma_bits = 0;
 			cfg = 0x00;	/* disable all DMA */
@@ -640,8 +640,8 @@ static void snd_es1688_free(void *private_data)
 }
 
 int snd_es1688_new_pcm(snd_card_t * card, int device,
-		       unsigned short port,
-		       unsigned short mpu_port,
+		       unsigned long port,
+		       unsigned long mpu_port,
 		       snd_irq_t * irqptr,
 		       snd_irq_t * mpu_irqptr,
 		       snd_dma_t * dma8ptr,
