@@ -552,9 +552,9 @@ void snd_opti93x_interrupt(snd_pcm_t *pcm, unsigned char status)
 		return;
 
 	status = snd_opti9xx_read(codec->chip, OPTi9XX_MC_REG(11));
-	if (status & OPTi93X_IRQ_PLAYBACK)
+	if ((status & OPTi93X_IRQ_PLAYBACK) && codec->playback_subchn)
 		snd_pcm_transfer_done(codec->playback_subchn);
-	if (status & OPTi93X_IRQ_CAPTURE) {
+	if ((status & OPTi93X_IRQ_CAPTURE) && codec->capture_subchn) {
 		snd_opti93x_overrange(codec);
 		snd_pcm_transfer_done(codec->capture_subchn);
 	}
