@@ -105,17 +105,21 @@ MODULE_PARM_DESC(osrun_time, "how many seconds to wait for the ICS2115 OS");
 /*
  *	This sucks, hopefully it'll get standardised
  */
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,2,18) && LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0)
+#define loops_per_sec loops_per_jiffy*HZ
+#endif
  
 #if defined(__alpha__) || defined(__powerpc__)
 #ifdef __SMP__
-#define LOOPS_PER_SEC cpu_data[smp_processor_id()].loops_per_sec
+#define LOOPS_PER_SEC	(cpu_data[smp_processor_id()].loops_per_sec)
 #else
-#define LOOPS_PER_SEC	loops_per_sec
+#define LOOPS_PER_SEC	(loops_per_sec)
 #endif
 #endif
 
 #if defined(__i386__)
-#define LOOPS_PER_SEC current_cpu_data.loops_per_sec
+#define LOOPS_PER_SEC	(current_cpu_data.loops_per_sec)
 #endif
  
 /* if WF_DEBUG not defined, no run-time debugging messages will
@@ -375,7 +379,7 @@ snd_wavefront_cmd (snd_wavefront_t *dev,
 	*/
 
 	if (cmd == WFC_DOWNLOAD_MULTISAMPLE) {
-		wfcmd->write_cnt = (unsigned int) rbuf;
+		wfcmd->write_cnt = (unsigned long) rbuf;
 		rbuf = 0;
 	}
 
@@ -907,11 +911,11 @@ wavefront_send_sample (snd_wavefront_t *dev,
 	int initial_skip = 0;
 
 	DPRINT (WF_DEBUG_LOAD_PATCH, "sample %sdownload for slot %d, "
-				      "type %d, %d bytes from 0x%x\n",
+				      "type %d, %d bytes from 0x%lx\n",
 				      header->size ? "" : "header ", 
 				      header->number, header->subkey,
 				      header->size,
-				      (int) header->dataptr);
+				      (long) header->dataptr);
 
 	if (header->number == WAVEFRONT_FIND_FREE_SAMPLE_SLOT) {
 		int x;
@@ -1250,7 +1254,7 @@ wavefront_send_multisample (snd_wavefront_t *dev, wavefront_patch_info *header)
 	*/
 
 	if (snd_wavefront_cmd (dev, WFC_DOWNLOAD_MULTISAMPLE, 
-			   (unsigned char *) ((num_samples*2)+3),
+			   (unsigned char *) (long) ((num_samples*2)+3),
 			   msample_hdr)) {
 		snd_printk (LOGNAME "download of multisample failed.\n");
 		return -(EIO);
