@@ -1,5 +1,6 @@
 /*
  *  Copyright (c) by Jaroslav Kysela <perex@suse.cz>
+ *                   Cirrus Logic, Inc.
  *  Routines for control of Cirrus Logic CS461x chips
  *
  *  BUGS:
@@ -98,7 +99,7 @@ static void snd_cs461x_codec_write(void *private_data,
 	snd_cs461x_pokeBA0(codec, BA0_ACCDA, val);
 	snd_cs461x_pokeBA0(codec, BA0_ACCTL, ACCTL_DCV | ACCTL_VFRM |
 				             ACCTL_ESYN | ACCTL_RSTN);
-	for (count = 0; count < 1000; count++) {
+	for (count = 0; count < 4000; count++) {
 		/*
 		 *  First, we want to wait for a short time.
 		 */
@@ -108,13 +109,9 @@ static void snd_cs461x_codec_write(void *private_data,
 		 *  ACCTL = 460h, DCV should be reset by now and 460h = 07h
 		 */
 		if (!(snd_cs461x_peekBA0(codec, BA0_ACCTL) & ACCTL_DCV))
-			break;
+			return;
 	}
-	/*
-	 *  Make sure the write completed.
-	 */
-	if (snd_cs461x_peekBA0(codec, BA0_ACCTL) & ACCTL_DCV)
-		snd_printk("cs461x: AC'97 write problem, reg = 0x%x, val = 0x%x\n", reg, val);
+	snd_printk("cs461x: AC'97 write problem, reg = 0x%x, val = 0x%x\n", reg, val);
 }
 
 static unsigned short snd_cs461x_codec_read(void *private_data,
@@ -157,7 +154,7 @@ static unsigned short snd_cs461x_codec_read(void *private_data,
 	/*
 	 *  Wait for the read to occur.
 	 */
-	for (count = 0; count < 500; count++) {
+	for (count = 0; count < 1000; count++) {
 		/*
 		 *  First, we want to wait for a short time.
 	 	 */
@@ -167,17 +164,13 @@ static unsigned short snd_cs461x_codec_read(void *private_data,
 		 *  ACCTL = 460h, DCV should be reset by now and 460h = 17h
 		 */
 		if (!(snd_cs461x_peekBA0(codec, BA0_ACCTL) & ACCTL_DCV))
-			break;
+			goto ok1;
 	}
 
-	/*
-	 *  Make sure the read completed.
-	 */
-	if (snd_cs461x_peekBA0(codec, BA0_ACCTL) & ACCTL_DCV) {
-		snd_printk("cs461x: AC'97 read problem (ACCTL_DCV), reg = 0x%x\n", reg);
-		return 0xffff;
-	}
+	snd_printk("cs461x: AC'97 read problem (ACCTL_DCV), reg = 0x%x\n", reg);
+	return 0xffff;
 
+ok1:
 	/*
 	 *  Wait for the valid status bit to go active.
 	 */
@@ -188,18 +181,14 @@ static unsigned short snd_cs461x_codec_read(void *private_data,
 		 *  VSTS - Valid Status
 		 */
 		if (snd_cs461x_peekBA0(codec, BA0_ACSTS) & ACSTS_VSTS)
-			break;
+			goto ok2;
 		udelay(10);
 	}
 	
-	/*
-	 *  Make sure we got valid status.
-	 */
-	if (!(snd_cs461x_peekBA0(codec, BA0_ACSTS) & ACSTS_VSTS)) {
-		snd_printk("cs461x: AC'97 read problem (ACSTS_VSTS), reg = 0x%x\n", reg);
-		return 0xffff;
-	}
+	snd_printk("cs461x: AC'97 read problem (ACSTS_VSTS), reg = 0x%x\n", reg);
+	return 0xffff;
 
+ok2:
 	/*
 	 *  Read the data returned from the AC97 register.
 	 *  ACSDA = Status Data Register = 474h
@@ -221,17 +210,19 @@ int snd_cs461x_download(cs461x_t *codec,
                         unsigned long offset,
                         unsigned long len)
 {
-	unsigned long counter;
 	unsigned int *dst;
 
 	if ((offset & 3) || (len & 3))
 		return -EINVAL;
 	dst = codec->ba1.idx[(offset >> 16) & 3];
-	offset &= 0xffff;
-	len >>= 2;
-	/* I'm not sure, if the big endian architecture needs the byteswap here */
-	for (counter = 0; counter < len; counter++)
-		dst[offset + counter] = src[counter];
+	dst += ((offset & 0xFFFF) << 2) / sizeof(unsigned int);
+	len /= sizeof(unsigned int);
+
+	/* writel already converts 32-bit value to right endianess */
+	while (len-- > 0) {
+		writel(*src++, dst);
+		dst++;
+	}
 	return 0;
 }
 
@@ -308,7 +299,8 @@ static void snd_cs461x_clear_serial_FIFOs(cs461x_t *codec)
 	 *  See if the devices are powered down.  If so, we must power them up first
 	 *  or they will not respond.
 	 */
-	if (!((tmp = snd_cs461x_peekBA0(codec, BA0_CLKCR1)) & CLKCR1_SWCE)) {
+	tmp = snd_cs461x_peekBA0(codec, BA0_CLKCR1);
+	if (!(tmp & CLKCR1_SWCE)) {
 		snd_cs461x_pokeBA0(codec, BA0_CLKCR1, tmp | CLKCR1_SWCE);
 		powerdown = 1;
 	}
@@ -1419,67 +1411,13 @@ static int snd_cs461x_proc_done(cs461x_t * codec)
 }
 
 /*
- *  initialization routines
+ *  initialize chip
  */
 
-int snd_cs461x_create(snd_card_t * card,
-		      struct pci_dev * pci,
-		      snd_dma_t * dma1ptr,
-		      snd_dma_t * dma2ptr,
-		      snd_irq_t * irqptr,
-		      cs461x_t ** rcodec)
+static int snd_cs461x_chip_init(cs461x_t *codec, int busywait)
 {
-	cs461x_t *codec;
-	unsigned short cmdw;
-	unsigned char cmdb;
 	unsigned int tmp;
-	int err;
-	signed long end_time;
-	static snd_device_ops_t ops = {
-		(snd_dev_free_t *)snd_cs461x_free,
-		NULL,
-		NULL
-	};
-	
-	*rcodec = NULL;
-	codec = snd_magic_kcalloc(cs461x_t, 0, GFP_KERNEL);
-	if (codec == NULL)
-		return -ENOMEM;
-	spin_lock_init(&codec->reg_lock);
-	codec->card = card;
-	codec->pci = pci;
-	codec->dma1ptr = dma1ptr;
-	codec->dma2ptr = dma2ptr;
-	codec->irqptr = irqptr;
-	codec->ba0_addr = pci_resource_start(pci, 0);
-	codec->ba1_addr = pci_resource_start(pci, 1);
-	if (codec->ba0_addr == 0 || codec->ba0_addr == ~0 ||
-	    codec->ba1_addr == 0 || codec->ba1_addr == ~0) {
-	    	snd_printk("cs461x: wrong address(es) - ba0 = 0x%lx, ba1 = 0x%lx\n", codec->ba0_addr, codec->ba1_addr);
-	    	snd_cs461x_free(codec);
-	    	return -ENOMEM;
-	}
-	codec->ba0 = ioremap(codec->ba0_addr, CS461X_BA0_SIZE);
-	codec->ba1.name.data0 = ioremap(codec->ba1_addr + BA1_SP_DMEM0, CS461X_BA1_DATA0_SIZE);
-	codec->ba1.name.data1 = ioremap(codec->ba1_addr + BA1_SP_DMEM1, CS461X_BA1_DATA1_SIZE);
-	codec->ba1.name.pmem = ioremap(codec->ba1_addr + BA1_SP_PMEM, CS461X_BA1_PRG_SIZE);
-	codec->ba1.name.reg = ioremap(codec->ba1_addr + BA1_SP_REG, CS461X_BA1_REG_SIZE);
-	if (codec->ba0 == NULL || codec->ba1.name.data0 == NULL ||
-	    codec->ba1.name.data1 == NULL || codec->ba1.name.pmem == NULL ||
-	    codec->ba1.name.reg == NULL) {
-		snd_cs461x_free(codec);
-		return -ENOMEM;
-	}
-	pci_set_master(pci);
-	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
-	if ((cmdw & PCI_COMMAND_MEMORY) != PCI_COMMAND_MEMORY) {
-		cmdw |= PCI_COMMAND_MEMORY;
-		pci_write_config_word(pci, PCI_COMMAND, cmdw);
-	}
-	pci_read_config_byte(pci, PCI_LATENCY_TIMER, &cmdb);
-	if (cmdb < 32)
-		cmdb = 32;
-	pci_write_config_byte(pci, PCI_LATENCY_TIMER, cmdb);
+	int timeout;
 
 	/* 
 	 *  First, blast the clock control register to zero so that the PLL starts
@@ -1503,7 +1441,7 @@ int snd_cs461x_create(snd_card_t * card,
          *  for a reset.
          */
         snd_cs461x_pokeBA0(codec, BA0_ACCTL, 0);
-        udelay(50);
+        udelay(500);
         snd_cs461x_pokeBA0(codec, BA0_ACCTL, ACCTL_RSTN);
 
 	/*
@@ -1518,7 +1456,7 @@ int snd_cs461x_create(snd_card_t * card,
 	 *  generating bit clock (so we don't try to start the PLL without an
 	 *  input clock).
 	 */
-	mdelay(1);
+	mdelay(10);
 
 	/*
 	 *  Set the serial port timing configuration, so that
@@ -1543,7 +1481,7 @@ int snd_cs461x_create(snd_card_t * card,
 	/*
          *  Wait until the PLL has stabilized.
 	 */
-	mdelay(1);
+	mdelay(100);
 
 	/*
 	 *  Turn on clocking of the core so that we can setup the serial ports.
@@ -1569,31 +1507,31 @@ int snd_cs461x_create(snd_card_t * card,
 	snd_cs461x_pokeBA0(codec, BA0_SERC2, SERC2_SI1F_AC97 | SERC1_SO1EN);
 	snd_cs461x_pokeBA0(codec, BA0_SERMC1, SERMC1_PTC_AC97 | SERMC1_MSPE);
 
+	mdelay(5);		/* Shouldnt be needed ?? */
+	
 	/*
 	 * Wait for the codec ready signal from the AC97 codec.
 	 */
-	end_time = jiffies + 3 * (HZ >> 2);
-	do {
+	timeout = 150;
+	while (timeout-- > 0) {
 		/*
 		 *  Read the AC97 status register to see if we've seen a CODEC READY
 		 *  signal from the AC97 codec.
 		 */
 		if (snd_cs461x_peekBA0(codec, BA0_ACSTS) & ACSTS_CRDY)
-			break;
-		set_current_state(TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
-	} while (end_time - (signed long)jiffies >= 0);
-
-	/*
-	 *  Make sure CODEC is READY.
-	 */
-	if (!(snd_cs461x_peekBA0(codec, BA0_ACSTS) & ACSTS_CRDY)) {
-		snd_printk("cs461x: create - never read codec ready from AC'97\n");
-		snd_printk("cs461x: it is not probably bug, try to use CS4236 driver\n");
-		snd_cs461x_free(codec);
-		return -EIO;
+			goto ok1;
+		if (busywait)
+			mdelay(10);
+		else {
+			set_current_state(TASK_UNINTERRUPTIBLE);
+			schedule_timeout((HZ+99)/100);
+		}
 	}
 
+	snd_printk("cs461x: create - never read codec ready from AC'97\n");
+	snd_printk("cs461x: it is not probably bug, try to use CS4236 driver\n");
+	return -EIO;
+ok1:
 	/*
 	 *  Assert the vaid frame signal so that we can start sending commands
 	 *  to the AC97 codec.
@@ -1604,28 +1542,25 @@ int snd_cs461x_create(snd_card_t * card,
 	 *  Wait until we've sampled input slots 3 and 4 as valid, meaning that
 	 *  the codec is pumping ADC data across the AC-link.
 	 */
-	end_time = jiffies + 3 * (HZ >> 2);
-	do {
+	timeout = 150;
+	while (timeout-- > 0) {
 		/*
 		 *  Read the input slot valid register and see if input slots 3 and
 		 *  4 are valid yet.
 		 */
 		if ((snd_cs461x_peekBA0(codec, BA0_ACISV) & (ACISV_ISV3 | ACISV_ISV4)) == (ACISV_ISV3 | ACISV_ISV4))
-			break;
-		set_current_state(TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
-	} while (end_time - (signed long)jiffies >= 0);
-
-	/*
-	 *  Make sure input slots 3 and 4 are valid.  If not, then return
-	 *  an error.
-	 */
-	if ((snd_cs461x_peekBA0(codec, BA0_ACISV) & (ACISV_ISV3 | ACISV_ISV4)) != (ACISV_ISV3 | ACISV_ISV4)) {
-		snd_printk("cs461x: create - never read ISV3 & ISV4 from AC'97\n");
-		snd_cs461x_free(codec);
-		return -EIO;
+			goto ok2;
+		if (busywait)
+			mdelay(10);
+		else {
+			set_current_state(TASK_UNINTERRUPTIBLE);
+			schedule_timeout((HZ+99)/100);
+		}
 	}
 
+	snd_printk("cs461x: create - never read ISV3 & ISV4 from AC'97\n");
+	return -EIO;
+ok2:
 	/*
 	 *  Now, assert valid frame and the slot 3 and 4 valid bits.  This will
 	 *  commense the transfer of digital audio data to the AC97 codec.
@@ -1655,7 +1590,6 @@ int snd_cs461x_create(snd_card_t * card,
 	 */
 	if (snd_cs461x_download_image(codec) < 0) {
 		snd_printk("cs461x: image download error\n");
-		snd_cs461x_free(codec);
 		return -EIO;
 	}
 
@@ -1673,6 +1607,8 @@ int snd_cs461x_create(snd_card_t * card,
 	codec->cctl = tmp & 0x0000ffff;
 	snd_cs461x_poke(codec, BA1_CCTL, tmp & 0xffff0000);
 
+	mdelay(5);		/* Do we need this ?? */
+	
 	snd_cs461x_powerup_adc(codec);
 	snd_cs461x_powerup_dac(codec);
 
@@ -1694,26 +1630,17 @@ int snd_cs461x_create(snd_card_t * card,
 	tmp &= ~0x0000003f;
 	tmp |=  0x00000001;
 	snd_cs461x_poke(codec, BA1_CIE, tmp);	/* capture interrupt enable */	
-
-	snd_cs461x_proc_init(card, codec);
-
-	if ((err = snd_device_new(card, SND_DEV_LOWLEVEL, codec, 0, &ops, NULL)) < 0) {
-		snd_cs461x_free(codec);
-		return err;
-	}
-
-	*rcodec = codec;
 	return 0;
 }
 
-int snd_cs461x_free(cs461x_t * codec)
+
+/*
+ * stop the h/w
+ */
+static void snd_cs461x_hw_stop(cs461x_t *codec)
 {
 	unsigned int tmp;
 
-	snd_debug_check(codec == NULL, -EINVAL);
-
-	snd_cs461x_proc_done(codec);
-
 	tmp = snd_cs461x_peek(codec, BA1_PFIE);
 	tmp &= ~0x0000f03f;
 	tmp |=  0x00000010;
@@ -1760,6 +1687,150 @@ int snd_cs461x_free(cs461x_t * codec)
 	 */
 	tmp = snd_cs461x_peekBA0(codec, BA0_CLKCR1) & ~CLKCR1_SWCE;
 	snd_cs461x_pokeBA0(codec, BA0_CLKCR1, tmp);
+}
+
+
+/*
+ * APM support
+ */
+#ifdef CONFIG_APM
+static int snd_cs461x_pm_callback(struct pm_dev *dev, pm_request_t rqst, void *data)
+{
+	cs461x_t *codec = snd_magic_cast(cs461x_t, dev->data, 0);
+	int i;
+
+	switch (rqst) {
+	case PM_SUSPEND:
+		if (codec->playback_subchn)
+			snd_cs461x_playback_trigger(codec, codec->playback_subchn, SND_PCM_TRIGGER_STOP);
+		
+		if (codec->capture_subchn)
+			snd_cs461x_capture_trigger(codec, codec->capture_subchn, SND_PCM_TRIGGER_STOP);
+
+		snd_cs461x_hw_stop(codec);
+		break;
+
+	case PM_RESUME:
+		snd_cs461x_chip_init(codec, 1);
+
+		/* restore ac97 registers */
+		for (i = 1; i <= SAVE_REG_MAX; i++) {
+			if (i == 0x04) /* AC97_REG_MASTER_TONE */
+				continue;
+			snd_cs461x_codec_write(codec, 2*i, codec->ac97->regs[i]);
+		}
+		if (codec->playback_subchn) {
+			snd_cs461x_playback_prepare(codec, codec->playback_subchn);
+			snd_cs461x_playback_trigger(codec, codec->playback_subchn, SND_PCM_TRIGGER_GO);
+		}
+		if (codec->capture_subchn) {
+			snd_cs461x_capture_prepare(codec, codec->capture_subchn);
+			snd_cs461x_capture_trigger(codec, codec->capture_subchn, SND_PCM_TRIGGER_GO);
+		}
+		break;
+	}
+	return 0;
+}
+#endif /* CONFIG_APM */
+
+
+/*
+ * create a cs461x card instance
+ */
+int snd_cs461x_create(snd_card_t * card,
+		      struct pci_dev * pci,
+		      snd_dma_t * dma1ptr,
+		      snd_dma_t * dma2ptr,
+		      snd_irq_t * irqptr,
+		      cs461x_t ** rcodec)
+{
+	cs461x_t *codec;
+	unsigned short cmdw;
+	unsigned char cmdb;
+	int err;
+	static snd_device_ops_t ops = {
+		(snd_dev_free_t *)snd_cs461x_free,
+		NULL,
+		NULL
+	};
+	
+	*rcodec = NULL;
+	codec = snd_magic_kcalloc(cs461x_t, 0, GFP_KERNEL);
+	if (codec == NULL)
+		return -ENOMEM;
+	spin_lock_init(&codec->reg_lock);
+	codec->card = card;
+	codec->pci = pci;
+	codec->dma1ptr = dma1ptr;
+	codec->dma2ptr = dma2ptr;
+	codec->irqptr = irqptr;
+	codec->ba0_addr = pci_resource_start(pci, 0);
+	codec->ba1_addr = pci_resource_start(pci, 1);
+	if (codec->ba0_addr == 0 || codec->ba0_addr == ~0 ||
+	    codec->ba1_addr == 0 || codec->ba1_addr == ~0) {
+	    	snd_printk("cs461x: wrong address(es) - ba0 = 0x%lx, ba1 = 0x%lx\n", codec->ba0_addr, codec->ba1_addr);
+	    	snd_cs461x_free(codec);
+	    	return -ENOMEM;
+	}
+	codec->ba0 = ioremap(codec->ba0_addr, CS461X_BA0_SIZE);
+	codec->ba1.name.data0 = ioremap(codec->ba1_addr + BA1_SP_DMEM0, CS461X_BA1_DATA0_SIZE);
+	codec->ba1.name.data1 = ioremap(codec->ba1_addr + BA1_SP_DMEM1, CS461X_BA1_DATA1_SIZE);
+	codec->ba1.name.pmem = ioremap(codec->ba1_addr + BA1_SP_PMEM, CS461X_BA1_PRG_SIZE);
+	codec->ba1.name.reg = ioremap(codec->ba1_addr + BA1_SP_REG, CS461X_BA1_REG_SIZE);
+	if (codec->ba0 == NULL || codec->ba1.name.data0 == NULL ||
+	    codec->ba1.name.data1 == NULL || codec->ba1.name.pmem == NULL ||
+	    codec->ba1.name.reg == NULL) {
+		snd_cs461x_free(codec);
+		return -ENOMEM;
+	}
+
+	pci_set_master(pci);
+	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
+	if ((cmdw & PCI_COMMAND_MEMORY) != PCI_COMMAND_MEMORY) {
+		cmdw |= PCI_COMMAND_MEMORY;
+		pci_write_config_word(pci, PCI_COMMAND, cmdw);
+	}
+	pci_read_config_byte(pci, PCI_LATENCY_TIMER, &cmdb);
+	if (cmdb < 32)
+		cmdb = 32;
+	pci_write_config_byte(pci, PCI_LATENCY_TIMER, cmdb);
+
+	err = snd_cs461x_chip_init(codec, 0);
+	if (err < 0) {
+		snd_cs461x_free(codec);
+		return err;
+	}
+
+	snd_cs461x_proc_init(card, codec);
+
+#ifdef CONFIG_APM
+	codec->pm_dev = pm_register(PM_PCI_DEV, 0, snd_cs461x_pm_callback);
+	if (codec->pm_dev)
+		codec->pm_dev->data = codec;
+#endif
+
+	if ((err = snd_device_new(card, SND_DEV_LOWLEVEL, codec, 0, &ops, NULL)) < 0) {
+		snd_cs461x_free(codec);
+		return err;
+	}
+
+	*rcodec = codec;
+	return 0;
+}
+
+int snd_cs461x_free(cs461x_t * codec)
+{
+	snd_debug_check(codec == NULL, -EINVAL);
+
+#ifdef CONFIG_APM
+	if (codec->pm_dev)
+		pm_unregister(codec->pm_dev);
+#endif
+
+	snd_cs461x_proc_done(codec);
+
+	if (codec->ba0)
+		snd_cs461x_hw_stop(codec);
 
 	if (codec->ba0)
 		iounmap(codec->ba0);
