@@ -57,8 +57,7 @@
  *  constants
  */
 
-#define POLL_COUNT	0x1000
-#define IO_DELAY	10
+#define POLL_COUNT	0xa000
 
 #ifdef CHIP1370
 static unsigned char bugbuf[16] __attribute__ ((aligned (16)));
@@ -76,12 +75,12 @@ static const unsigned int snd_ensoniq_sample_shift[] =
 
 static unsigned int snd_es1371_wait_src_ready(ensoniq_t * ensoniq)
 {
-	unsigned int t, r;
+	unsigned int t, r = 0;
 
 	for (t = 0; t < POLL_COUNT; t++) {
-		if (!((r = inl(ES_REG(ensoniq, 1371_SMPRATE))) & ES_1371_SRC_RAM_BUSY))
+		r = inl(ES_REG(ensoniq, 1371_SMPRATE));
+		if ((r & ES_1371_SRC_RAM_BUSY) == 0)
 			return r;
-		udelay(1);
 	}
 	snd_printk("es1371: wait source ready timeout 0x%lx [0x%x]\n", ES_REG(ensoniq, 1371_SMPRATE), r);
 	return 0;
@@ -109,7 +108,6 @@ static unsigned int snd_es1371_src_read(ensoniq_t * ensoniq, unsigned short reg)
 			temp = inl(ES_REG(ensoniq, 1371_SMPRATE));
 			if ((temp & 0x00870000) == 0x00010000)
 				break;
-			udelay(IO_DELAY);
 		}
 	}
 
@@ -186,13 +184,11 @@ static void snd_es1371_codec_write(void *private_data,
 			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00000000)
 					break;
-				udelay(IO_DELAY);
 			}
 			/* wait for a SAFE time to write addr/data and then do it, dammit */
 			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00010000)
 					break;
-				udelay(IO_DELAY);
 			}
 			outl(ES_1371_CODEC_WRITE(reg, val), ES_REG(ensoniq, 1371_CODEC));
 			/* restore SRC reg */
@@ -227,13 +223,11 @@ static unsigned short snd_es1371_codec_read(void *private_data,
 			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00000000)
 					break;
-				udelay(IO_DELAY);
 			}
 			/* wait for a SAFE time to write addr/data and then do it, dammit */
 			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00010000)
 					break;
-				udelay(IO_DELAY);
 			}
 			outl(ES_1371_CODEC_READS(reg), ES_REG(ensoniq, 1371_CODEC));
 			/* restore SRC reg */
@@ -243,7 +237,6 @@ static unsigned short snd_es1371_codec_read(void *private_data,
 			for (t = 0; t < POLL_COUNT; t++) {
 				if (!(inl(ES_REG(ensoniq, 1371_CODEC)) & ES_1371_CODEC_WIP))
 					break;		
-				udelay(IO_DELAY);
 			}
 			/* now wait for the stinkin' data (RDY) */
 			for (t = 0; t < POLL_COUNT; t++) {
@@ -1425,9 +1418,13 @@ int snd_ensoniq_create(snd_card_t * card,
 	if (pci->vendor == PCI_VENDOR_ID_ENSONIQ &&
 	    ((pci->device == PCI_DEVICE_ID_ENSONIQ_CT5880 &&
 	      ensoniq->rev == CT5880REV_CT5880_C) ||
+	     (pci->device == PCI_DEVICE_ID_ENSONIQ_CT5880 &&
+	      ensoniq->rev == CT5880REV_CT5880_D) ||
 	     (pci->device == PCI_DEVICE_ID_ENSONIQ_ES1371 &&
-	      ensoniq->rev == ES1371REV_CT5880_A))) {
-	        unsigned long tmo;
+	      ensoniq->rev == ES1371REV_CT5880_A) ||
+	     (pci->device == PCI_DEVICE_ID_ENSONIQ_ES1371 &&
+	      ensoniq->rev == ES1371REV_ES1373_8))) {
+		unsigned long tmo;
                 signed long tmo2;
 
 		ensoniq->cssr |= ES_1371_ST_AC97_RST;
