@@ -261,7 +261,8 @@ static int snd_intel8x0_playback_prepare(void *private_data,
 	codec->playback.fragsize = snd_pcm_lib_transfer_fragment(subchn);
 	/* disable DAC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_POWERDOWN, ~0x0200, 0x0200);
-	snd_ac97_write_lock(codec->ac97, AC97_PCM_FRONT_DAC_RATE, runtime->format.rate);
+	snd_ac97_write_lock(codec->ac97, AC97_PCM_FRONT_DAC_RATE,
+			    (codec->ac97_clock * runtime->format.rate) / 48000);
 	/* enable DAC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_POWERDOWN, ~0x0200, 0x0000);
 #if 0
@@ -288,7 +289,8 @@ static int snd_intel8x0_capture_prepare(void *private_data,
 	codec->capture.fragsize = snd_pcm_lib_transfer_fragment(subchn);
 	/* disable ADC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_POWERDOWN, ~0x0100, 0x0100);
-	snd_ac97_write_lock(codec->ac97, AC97_PCM_LR_ADC_RATE, runtime->format.rate);
+	snd_ac97_write_lock(codec->ac97, AC97_PCM_LR_ADC_RATE,
+			    (codec->ac97_clock * runtime->format.rate) / 48000);
 	/* enable ADC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_POWERDOWN, ~0x0100, 0x0000);
 	spin_lock_irqsave(&codec->reg_lock, flags);
@@ -520,7 +522,8 @@ static int snd_intel8x0_capture_mic_prepare(void *private_data,
 	codec->capture_mic.fragsize = snd_pcm_lib_transfer_fragment(subchn);
 	/* disable ADC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_EXTENDED_STATUS, ~0x4000, 0x4000);
-	snd_ac97_write_lock(codec->ac97, AC97_PCM_MIC_ADC_RATE, runtime->format.rate);
+	snd_ac97_write_lock(codec->ac97, AC97_PCM_MIC_ADC_RATE,
+			    (codec->ac97_clock * runtime->format.rate) / 48000);
 	/* enable ADC power */
 	snd_ac97_write_bitmask_lock(codec->ac97, AC97_EXTENDED_STATUS, ~0x4000, 0x0000);
 	spin_lock_irqsave(&codec->reg_lock, flags);
@@ -640,7 +643,17 @@ int snd_intel8x0_pcm_mic(intel8x0_t * codec, int device, snd_pcm_t ** rpcm)
 static void snd_intel8x0_codec_init(void *private_data, ac97_t *ac97)
 {
 	intel8x0_t *codec = snd_magic_cast(intel8x0_t, private_data, );
+	int idx;
 
+	for (idx=10; idx--;) {
+		if ((snd_ac97_read(ac97, AC97_POWERDOWN) & 0x0f) == 0x0f)
+			goto __ready_ok;
+		current->state = TASK_UNINTERRUPTIBLE;
+		schedule_timeout(HZ / 10);
+	}
+	snd_printk("snd_intel8x0_chip_init: Analog subsections not ready.\n");
+
+__ready_ok:
 	if (codec->ac97_ext_id & 0x0001)	/* VRA */
 		snd_ac97_write_lock(ac97, AC97_EXTENDED_STATUS, 0x0009);	
 	/* disable DAC & ADC power */
@@ -683,10 +696,12 @@ int snd_intel8x0_mixer(intel8x0_t * codec, int device, int pcm_count, int *pcm_d
 static int snd_intel8x0_test_rate(intel8x0_t *codec, int reg, int rate)
 {
 	unsigned short val;
+	unsigned int tmp;
 
-	snd_intel8x0_codec_write(codec, reg, rate);
+	tmp = ((unsigned int)rate * codec->ac97_clock) / 48000;
+	snd_intel8x0_codec_write(codec, reg, tmp & 0xffff);
 	val = snd_intel8x0_codec_read(codec, reg);
-	return val == rate;
+	return val == (tmp & 0xffff);
 }
 
 static void snd_intel8x0_determine_rates(intel8x0_t *codec, int reg, unsigned int *r_result)
@@ -718,13 +733,25 @@ static int snd_intel8x0_chip_init(intel8x0_t *codec)
 {
 	unsigned short ext_id;
 	signed long end_time;
-	
-	/* ACLink on, warm reset */
-	outl(ICH_AC97WARM | ICH_AC97COLD, ICHREG(codec, GLOB_CNT));
+	unsigned int cnt;
+
+	/* put logic to right state */
+	/* first clear status bits */
+	cnt =  inl(ICHREG(codec, GLOB_STA));
+	outl(cnt & (ICH_RCS | ICH_MCINT | ICH_POINT | ICH_PIINT), ICHREG(codec, GLOB_STA));
+
+	/* ACLink on, 2 channels */
+	cnt = inl(ICHREG(codec, GLOB_CNT));
+	cnt &= ~(ICH_ACLINK | ICH_PCM_246_MASK);
+	/* finish cold or do warm reset */
+	cnt |= (cnt & ICH_AC97COLD) == 0 ? ICH_AC97COLD : ICH_AC97WARM;
+	outl(cnt, ICHREG(codec, GLOB_CNT));
 	end_time = jiffies + (HZ >> 2);
 	do {
 		if ((inl(ICHREG(codec, GLOB_CNT)) & ICH_AC97WARM) == 0)
 			goto __ok;
+		set_current_state(TASK_UNINTERRUPTIBLE);
+		schedule_timeout(1);
 	} while (end_time - (signed long)jiffies >= 0);
 	snd_printk("AC'97 warm reset still in progress? [0x%x]\n", inl(ICHREG(codec, GLOB_CNT)));
 
@@ -774,6 +801,7 @@ int snd_intel8x0_create(snd_card_t * card,
 		        snd_dma_t * dma_cap,
 		        snd_dma_t * dma_mic,
 			snd_irq_t * irqptr,
+			unsigned int ac97_clock,
 		        intel8x0_t ** r_intel8x0)
 {
 	intel8x0_t *codec;
@@ -826,6 +854,10 @@ int snd_intel8x0_create(snd_card_t * card,
 	codec->playback.bdbar = (unsigned int *)(((unsigned long)codec->bdbars + 7) & ~7);
 	codec->capture.bdbar = codec->playback.bdbar + 32 * 2;
 	codec->capture_mic.bdbar = codec->capture.bdbar + 32 * 2;
+	if (ac97_clock >= 8000 && ac97_clock <= 48000)
+		codec->ac97_clock = ac97_clock;
+	else
+		codec->ac97_clock = 48000;
 
 	if ((err = snd_intel8x0_chip_init(codec)) < 0) {
 		snd_intel8x0_free(codec);
