@@ -336,16 +336,16 @@ int snd_rme9652_free (rme9652_t * rme9652)
 static int __init snd_rme9652_initialize_memory (rme9652_t * rme9652)
 
 {
-	u32 pb;
-	u32 cb;
+	u_long pb;
+	u_long cb;
 
 	/* Here the hard time: need a 1664kB physical continuous
 	   memory for record and play buffers ???? 
 	*/
 
 #ifdef RME9652_PREALLOCATE_MEMORY
-	cb = (u32) snd_rme9652_get_buffer ();
-	pb = (u32) snd_rme9652_get_buffer ();
+	cb = (u_long) snd_rme9652_get_buffer ();
+	pb = (u_long) snd_rme9652_get_buffer ();
 #else
 	cb = snd_malloc_pages (RME9652_DMA_AREA_BYTES(rme9652), &pg, 1);
 	pb = snd_malloc_pages (RME9652_DMA_AREA_BYTES(rme9652), &pg, 1);
