@@ -120,7 +120,7 @@ static void sample_start(trident_t * trident, snd_trident_voice_t * voice, snd_s
 	simple_instrument_t *simple;
 	snd_seq_kinstr_t *instr;
 	unsigned long flags;
-	unsigned int loop_start, loop_end, sample_start, sample_end;
+	unsigned int loop_start, loop_end, sample_start, sample_end, start_offset;
 	unsigned int value;
 
 	instr = snd_seq_instr_find(trident->synth.ilist, &voice->instr, 0, 1);
@@ -139,8 +139,11 @@ static void sample_start(trident_t * trident, snd_trident_voice_t * voice, snd_s
 		loop_end = 2*(simple->loop_end >> 4) - (simple->loop_start >> 4);
 	else
 		loop_end = simple->loop_end >> 4;
-	sample_start = simple->start >> 4;
+	sample_start = (simple->start + position) >> 4;
+	if( sample_start >= simple->size )
+		sample_start = simple->start >> 4;
 	sample_end = simple->size;
+	start_offset = position >> 4;
 
 	if (simple->format & SIMPLE_WAVE_16BIT)
 		voice->CTRL |= 8;
@@ -152,8 +155,13 @@ static void sample_start(trident_t * trident, snd_trident_voice_t * voice, snd_s
 	if (simple->format & SIMPLE_WAVE_LOOP) {
 		voice->CTRL |= 1;
 		voice->LBA = virt_to_bus(simple->address.ptr + loop_start);
-		voice->CSO = loop_start;
-		voice->negCSO = 1;
+		if( start_offset >= loop_start ) {
+			voice->CSO = start_offset - loop_start;
+			voice->negCSO = 0;
+		} else {
+			voice->CSO = loop_start - start_offset;
+			voice->negCSO = 1;
+		}
 		voice->ESO = loop_end - loop_start - 1;
 	} else {
 		voice->LBA = virt_to_bus(simple->address.ptr);
@@ -702,7 +710,7 @@ int snd_trident_synth_event_input(snd_seq_event_t * ev, int direct, void *privat
 	if (p == NULL)
 		return -EINVAL;
 	if (ev->type >= SND_SEQ_EVENT_SAMPLE &&
-	    ev->type <= SND_SEQ_EVENT_SAMPLE_POSITION) {
+	    ev->type <= SND_SEQ_EVENT_SAMPLE_PRIVATE1) {
 		snd_trident_sample_event(ev, p);
 		return 0;
 	}
