@@ -337,6 +337,26 @@ static void snd_ymfpci_pcm_capture_interrupt(snd_pcm_subchn_t *substream)
 	spin_unlock(&codec->reg_lock);
 }
 
+static int snd_ymfpci_set_frag_size(snd_pcm_subchn_t *substream)
+{
+	snd_pcm_runtime_t *runtime = substream->runtime;
+	u32 frag_size, buf_size;
+
+	frag_size = ((u32)runtime->format.rate << 16) / 48000;
+	frag_size >>= 8;
+	if (snd_pcm_format_width(runtime->format.format) == 16)
+		frag_size <<= 1;
+	if (runtime->format.voices == 2)
+		frag_size <<= 1;
+	if (frag_size == 0)
+		return -EINVAL;
+	buf_size = snd_pcm_lib_transfer_size(substream);
+	if (runtime->buf.block.frag_size < frag_size)
+		runtime->buf.block.frag_size = frag_size;
+	snd_pcm_lib_set_buffer_size(substream, buf_size);
+	return 0;
+}
+
 static int snd_ymfpci_playback_ioctl(void *private_data,
 				     snd_pcm_subchn_t * substream,
 				     unsigned int cmd,
@@ -348,20 +368,9 @@ static int snd_ymfpci_playback_ioctl(void *private_data,
 	result = snd_pcm_lib_ioctl(private_data, substream, cmd, arg);
 	if (result < 0)
 		return result;		
-	if (cmd == SND_PCM_IOCTL1_PARAMS) {
-		if (runtime->mode == SND_PCM_MODE_BLOCK) {
-			u32 tmp;
-			tmp = (u32)runtime->format.rate << 16;
-			tmp /= 48000;
-			tmp >>= 8;
-			if (snd_pcm_format_width(runtime->format.format) == 16)
-				tmp <<= 1;
-			if (runtime->format.voices == 2)
-				tmp <<= 1;
-			runtime->frags = snd_pcm_lib_transfer_size(substream) / tmp;
-			runtime->buf.block.frag_size = tmp;
-			snd_pcm_lib_set_buffer_size(substream, runtime->frags * runtime->buf.block.frag_size);
-		}
+	if (cmd == SND_PCM_IOCTL1_PARAMS &&
+	    runtime->mode == SND_PCM_MODE_BLOCK) {
+		result = snd_ymfpci_set_frag_size(substream);
 	}
 	return result;
 }
@@ -377,20 +386,9 @@ static int snd_ymfpci_capture_ioctl(void *private_data,
 	result = snd_pcm_lib_ioctl(private_data, substream, cmd, arg);
 	if (result < 0)
 		return result;		
-	if (cmd == SND_PCM_IOCTL1_PARAMS) {
-		if (runtime->mode == SND_PCM_MODE_BLOCK) {
-			u32 tmp;
-			tmp = (u32)runtime->format.rate << 16;
-			tmp /= 48000;
-			tmp >>= 8;
-			if (snd_pcm_format_width(runtime->format.format) == 16)
-				tmp <<= 1;
-			if (runtime->format.voices == 2)
-				tmp <<= 1;
-			runtime->frags = snd_pcm_lib_transfer_size(substream) / tmp;
-			runtime->buf.block.frag_size = tmp;
-			snd_pcm_lib_set_buffer_size(substream, runtime->frags * runtime->buf.block.frag_size);
-		}
+	if (cmd == SND_PCM_IOCTL1_PARAMS &&
+	    runtime->mode == SND_PCM_MODE_BLOCK) {
+		result = snd_ymfpci_set_frag_size(substream);
 	}
 	return result;
 }
@@ -686,11 +684,6 @@ void snd_ymfpci_interrupt(ymfpci_t *codec)
 
 	status = snd_ymfpci_readl(codec, YDSXGR_STATUS);
 	if (status & 0x80000000) {
-		spin_lock(&codec->reg_lock);
-		snd_ymfpci_writel(codec, YDSXGR_STATUS, 0x80000000);
-		mode = snd_ymfpci_readl(codec, YDSXGR_MODE) | 2;
-		snd_ymfpci_writel(codec, YDSXGR_MODE, mode);
-		spin_unlock(&codec->reg_lock);
 		codec->active_bank = snd_ymfpci_readl(codec, YDSXGR_CTRLSELECT);
 		spin_lock(&codec->voice_lock);
 		for (nvoice = 0; nvoice < 64; nvoice++) {
@@ -703,6 +696,11 @@ void snd_ymfpci_interrupt(ymfpci_t *codec)
 				snd_ymfpci_pcm_capture_interrupt(codec->capture_substream[nvoice]);
 		}
 		spin_unlock(&codec->voice_lock);
+		spin_lock(&codec->reg_lock);
+		snd_ymfpci_writel(codec, YDSXGR_STATUS, 0x80000000);
+		mode = snd_ymfpci_readl(codec, YDSXGR_MODE) | 2;
+		snd_ymfpci_writel(codec, YDSXGR_MODE, mode);
+		spin_unlock(&codec->reg_lock);
 	}
 
 	status = snd_ymfpci_readl(codec, YDSXGR_INTFLAG);
@@ -726,9 +724,9 @@ static snd_pcm_hardware_t snd_ymfpci_playback =
 	max_rate:		48000,
 	min_voices:		1,
 	max_voices:		2,
-	min_fragment_size:	32,
+	min_fragment_size:	256,
 	max_fragment_size:	256 * 1024, /* XXX */
-	fragment_align:		1,
+	fragment_align:		3,
 	fifo_size:		0,
 	transfer_block_size:	4,
 	ioctl:			snd_ymfpci_playback_ioctl,
@@ -751,9 +749,9 @@ static snd_pcm_hardware_t snd_ymfpci_capture =
 	max_rate:		48000,
 	min_voices:		1,
 	max_voices:		2,
-	min_fragment_size:	32,
+	min_fragment_size:	256,
 	max_fragment_size:	256 * 1024, /* XXX */
-	fragment_align:		1,
+	fragment_align:		3,
 	fifo_size:		0,
 	transfer_block_size:	4,
 	ioctl:			snd_ymfpci_capture_ioctl,
@@ -1081,7 +1079,7 @@ int snd_ymfpci_pcm_spdif(ymfpci_t * codec, int device, snd_pcm_t ** rpcm)
 	pcm->chn[SND_PCM_CHANNEL_PLAYBACK].close = snd_ymfpci_playback_spdif_close;
 
 	/* global setup */
-	pcm->info_flags = SND_PCM_INFO_CAPTURE;
+	pcm->info_flags = SND_PCM_INFO_PLAYBACK;
 	strcpy(pcm->name, "YMFPCI - S/PDIF");
 	*rpcm = codec->pcm = pcm;
 	return 0;
@@ -1324,7 +1322,7 @@ static void snd_ymfpci_disable_dsp(ymfpci_t *codec)
 	if (val)
 		snd_ymfpci_writel(codec, YDSXGR_CONFIG, 0x00000000);
 	while (timeout-- > 0) {
-		val = snd_ymfpci_readl(codec, YDSXGR_CONFIG);
+		val = snd_ymfpci_readl(codec, YDSXGR_STATUS);
 		if ((val & 0x00000002) == 0)
 			break;
 	}
@@ -1334,7 +1332,7 @@ static void snd_ymfpci_disable_dsp(ymfpci_t *codec)
 
 static void snd_ymfpci_download_image(ymfpci_t *codec)
 {
-	int i, ver_1e;
+	int i;
 	u16 ctrl;
 
 	snd_ymfpci_writel(codec, YDSXGR_NATIVEDACOUTVOL, 0x00000000);
@@ -1354,23 +1352,20 @@ static void snd_ymfpci_download_image(ymfpci_t *codec)
 		snd_ymfpci_writel(codec, YDSXGR_DSPINSTRAM + i, DspInst[i >> 2]);
 
 	switch (codec->device_id) {
-	case PCI_DEVICE_ID_YAMAHA_724F:
-	case PCI_DEVICE_ID_YAMAHA_740C:
 	case PCI_DEVICE_ID_YAMAHA_744:
 	case PCI_DEVICE_ID_YAMAHA_754:
-		ver_1e = 1;
 		break;
-	default:
-		ver_1e = 0;
-	}
-
-	if (ver_1e) {
+	case PCI_DEVICE_ID_YAMAHA_724F:
+	case PCI_DEVICE_ID_YAMAHA_740C:
 		/* setup control instruction code */
 		for (i = 0; i < YDSXG_CTRLLENGTH; i++)
 			snd_ymfpci_writel(codec, YDSXGR_CTRLINSTRAM + i, CntrlInst1E[i >> 2]);
-	} else {
+		break;
+	default:
+		/* setup control instruction code */
 		for (i = 0; i < YDSXG_CTRLLENGTH; i++)
 			snd_ymfpci_writel(codec, YDSXGR_CTRLINSTRAM + i, CntrlInst[i >> 2]);
+		break;
 	}
 
 	snd_ymfpci_enable_dsp(codec);
@@ -1386,7 +1381,11 @@ static int snd_ymfpci_memalloc(ymfpci_t *codec)
 	codec->bank_size_playback = snd_ymfpci_readl(codec, YDSXGR_PLAYCTRLSIZE) << 2;
 	codec->bank_size_capture = snd_ymfpci_readl(codec, YDSXGR_RECCTRLSIZE) << 2;
 	codec->bank_size_effect = snd_ymfpci_readl(codec, YDSXGR_EFFCTRLSIZE) << 2;
+#if 0
 	codec->work_size = YDSXG_DEFAULT_WORK_SIZE;
+#else
+	codec->work_size = snd_ymfpci_readl(codec, YDSXGR_WORKSIZE) << 2;
+#endif
 	
 	size = ((playback_ctrl_size + 0x00ff) & ~0x00ff) +
 	       ((codec->bank_size_playback * 2 * YDSXG_PLAYBACK_VOICES + 0x00ff) & ~0x00ff) +
@@ -1434,7 +1433,9 @@ static int snd_ymfpci_memalloc(ymfpci_t *codec)
 	snd_ymfpci_writel(codec, YDSXGR_RECCTRLBASE, virt_to_bus(codec->bank_base_capture));
 	snd_ymfpci_writel(codec, YDSXGR_EFFCTRLBASE, virt_to_bus(codec->bank_base_effect));
 	snd_ymfpci_writel(codec, YDSXGR_WORKBASE, virt_to_bus(codec->work_base));
+#if 0
 	snd_ymfpci_writel(codec, YDSXGR_WORKSIZE, codec->work_size >> 2);
+#endif
 
 	/* S/PDIF output initialization */
 	snd_ymfpci_writew(codec, YDSXGR_SPDIFOUTCTRL, 0);
@@ -1444,7 +1445,7 @@ static int snd_ymfpci_memalloc(ymfpci_t *codec)
 		(SND_PCM_AES1_CON_PCM_CODER << 8));
 
 	/* S/PDIF input initialization */
-	snd_ymfpci_writew(codec, YDSXGR_SPDIFINCTRL, 0);
+	snd_ymfpci_writew(codec, YDSXGR_SPDIFINCTRL, 1);
 
 	/* move this volume setup to mixer */
 	snd_ymfpci_writel(codec, YDSXGR_NATIVEDACOUTVOL, 0x3fff3fff);
