@@ -294,7 +294,6 @@ void snd_sb16dsp_interrupt(snd_pcm_t * pcm, unsigned short status)
 {
 	int ok;
 	sbdsp_t *codec = snd_magic_cast(sbdsp_t, pcm->private_data, );
-	unsigned long flags;
 
 #if 0
 	PRINTK("sb16: interrupt - status = 0x%x\n", status);
@@ -309,7 +308,7 @@ void snd_sb16dsp_interrupt(snd_pcm_t * pcm, unsigned short status)
 			snd_pcm_transfer_done(codec->capture_subchn);
 			ok++;
 		}
-		spin_lock_irqsave(&codec->reg_lock, flags);
+		spin_lock(&codec->reg_lock);
 #ifdef CONFIG_SND_SB16_CSP
 		if (codec->hardware == SB_HW_16CSP) {
 			snd_sb_csp_t *csp = snd_magic_cast(snd_sb_csp_t, codec->csp_private_data, );
@@ -322,7 +321,7 @@ void snd_sb16dsp_interrupt(snd_pcm_t * pcm, unsigned short status)
 		if (!ok)
 			snd_sb16dsp_command(codec, SB_DSP_DMA8_OFF);
 		snd_sb16_ack_8bit(codec);
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
+		spin_unlock(&codec->reg_lock);
 	}
 	if (status & SB_IRQTYPE_16BIT) {
 		ok = 0;
@@ -334,7 +333,7 @@ void snd_sb16dsp_interrupt(snd_pcm_t * pcm, unsigned short status)
 			snd_pcm_transfer_done(codec->capture_subchn);
 			ok++;
 		}
-		spin_lock_irqsave(&codec->reg_lock, flags);
+		spin_lock(&codec->reg_lock);
 #ifdef CONFIG_SND_SB16_CSP
 		if (codec->hardware == SB_HW_16CSP) {
 			snd_sb_csp_t *csp = snd_magic_cast(snd_sb_csp_t, codec->csp_private_data, );
@@ -347,7 +346,7 @@ void snd_sb16dsp_interrupt(snd_pcm_t * pcm, unsigned short status)
 		if (!ok)
 			snd_sb16dsp_command(codec, SB_DSP_DMA16_OFF);
 		snd_sb16_ack_16bit(codec);
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
+		spin_unlock(&codec->reg_lock);
 	}
 }
 
