@@ -99,13 +99,13 @@ static void snd_sb8_compute_rate(snd_pcm_subchn_t * subchn)
 			}
 		}
 		runtime->format.rate = (256000000 / (65536 - (codec->speed8 << 8))) / runtime->format.voices;
-#if 0
-		snd_printd(__FUNCTION__ ": rate = %u, pchn->real_rate = %u\n", rate, pchn->real_rate);
-#endif
 		break;
 	default:
 		snd_printd("unknown hardware for sb8 compute rate!!!\n");
 	}
+#if 0
+	snd_printd(__FUNCTION__ ": rate = %u, pchn->real_rate = %u\n", rate, runtime->format.rate);
+#endif
 }
 
 static int snd_sb8_playback_ioctl(void *private_data,
@@ -149,7 +149,7 @@ static int snd_sb8_playback_prepare(void *private_data,
 		snd_sb8_ack_8bit(codec);
 		snd_sb8dsp_command(codec, SB_DSP_SPEAKER_ON);
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
-		snd_dma_program(codec->dma8, &runtime->dma_area->buf[runtime->buf_position % codec->p_dma_size], codec->p_dma_size, DMA_MODE_WRITE);
+		snd_dma_program(codec->dma8, runtime->dma_area->buf, codec->p_dma_size, DMA_MODE_WRITE);
 		break;
 	case SB_HW_20:
 	case SB_HW_201:
@@ -216,6 +216,7 @@ static int snd_sb8_playback_trigger(void *private_data,
 			snd_sb8dsp_reset(codec);
 			codec->mode8 = SB_MODE8_HALT;
 		} else {
+			spin_unlock_irqrestore(&codec->reg_lock, flags);
 			return -EINVAL;
 		}
 		break;
@@ -231,6 +232,7 @@ static int snd_sb8_playback_trigger(void *private_data,
 			} else if (cmd == SND_PCM_TRIGGER_STOP) {
 				snd_sb8dsp_reset(codec);
 			} else {
+				spin_unlock_irqrestore(&codec->reg_lock, flags);
 				return -EINVAL;
 			}
 		} else {
@@ -239,6 +241,7 @@ static int snd_sb8_playback_trigger(void *private_data,
 			} else if (cmd == SND_PCM_TRIGGER_STOP) {
 				snd_sb8dsp_command(codec, SB_DSP_DMA8_OFF);
 			} else {
+				spin_unlock_irqrestore(&codec->reg_lock, flags);
 				return -EINVAL;
 			}
 		}
@@ -267,7 +270,7 @@ static int snd_sb8_capture_prepare(void *private_data,
 		snd_sb8dsp_command(codec, codec->speed8);
 		snd_sb8_ack_8bit(codec);
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
-		snd_dma_program(codec->dma8, &runtime->dma_area->buf[runtime->buf_position % codec->c_dma_size], codec->c_dma_size, DMA_MODE_READ);
+		snd_dma_program(codec->dma8, runtime->dma_area->buf, codec->c_dma_size, DMA_MODE_READ);
 		break;
 	case SB_HW_20:
 	case SB_HW_201:
@@ -336,6 +339,7 @@ static int snd_sb8_capture_trigger(void *private_data,
 			snd_sb8dsp_reset(codec);
 			codec->mode8 = SB_MODE8_HALT;
 		} else {
+			spin_unlock_irqrestore(&codec->reg_lock, flags);
 			return -EINVAL;
 		}
 		break;
@@ -351,6 +355,7 @@ static int snd_sb8_capture_trigger(void *private_data,
 			} else if (cmd == SND_PCM_TRIGGER_STOP) {
 				snd_sb8dsp_reset(codec);
 			} else {
+				spin_unlock_irqrestore(&codec->reg_lock, flags);
 				return -EINVAL;
 			}
 		} else {
@@ -359,6 +364,7 @@ static int snd_sb8_capture_trigger(void *private_data,
 			} else if (cmd == SND_PCM_TRIGGER_STOP) {
 				snd_sb8dsp_command(codec, SB_DSP_DMA8_OFF);
 			} else {
+				spin_unlock_irqrestore(&codec->reg_lock, flags);
 				return -EINVAL;
 			}
 		}
@@ -384,7 +390,7 @@ void snd_sb8dsp_interrupt(snd_pcm_t * pcm)
 		if ((codec->hardware == SB_HW_10 ||
 		     codec->hardware == SB_HW_20) &&
 		    *subchn->runtime->status == SND_PCM_STATUS_RUNNING) {
-		    	snd_sb8_playback_prepare(runtime->private_data, subchn);
+			snd_dma_program(codec->dma8, &runtime->dma_area->buf[runtime->buf_position % codec->p_dma_size], codec->p_dma_size, DMA_MODE_WRITE);
 		    	snd_sb8_playback_trigger(runtime->private_data, subchn, SND_PCM_TRIGGER_GO);
 		}
 		break;
@@ -395,7 +401,7 @@ void snd_sb8dsp_interrupt(snd_pcm_t * pcm)
 		if ((codec->hardware == SB_HW_10 ||
 		     codec->hardware == SB_HW_20) &&
 		    *subchn->runtime->status == SND_PCM_STATUS_RUNNING) {
-		    	snd_sb8_capture_prepare(runtime->private_data, subchn);
+			snd_dma_program(codec->dma8, &runtime->dma_area->buf[runtime->buf_position % codec->c_dma_size], codec->c_dma_size, DMA_MODE_READ);
 		    	snd_sb8_capture_trigger(runtime->private_data, subchn, SND_PCM_TRIGGER_GO);
 		}
 		break;
